/* original parser id follows */
/* yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93" */
/* (use YYMAJOR/YYMINOR for ifdefs dependent on parser version) */

#define YYBYACC 1
#define YYMAJOR 2
#define YYMINOR 0
#define YYPATCH 20230219

#define YYEMPTY        (-1)
#define yyclearin      (yychar = YYEMPTY)
#define yyerrok        (yyerrflag = 0)
#define YYRECOVERING() (yyerrflag != 0)
#define YYENOMEM       (-2)
#define YYEOF          0
#undef YYBTYACC
#define YYBTYACC 0
#define YYDEBUGSTR YYPREFIX "debug"
#define YYPREFIX "yy"

#define YYPURE 0

#line 22 "parse.y"
#include <sys/types.h>
#include <sys/stat.h>

#include <ctype.h>
#include <grp.h>
#include <pwd.h>
#include <string.h>
#include <syslog.h>

#include "fdm.h"
#include "deliver.h"
#include "fetch.h"
#include "match.h"

struct strb	*parse_tags;
struct macros	 parse_macros;
struct macro	*parse_last;	/* last command-line argument macro */

u_int		 parse_ruleidx;
u_int		 parse_actionidx;

ARRAY_DECL(, struct rule *) parse_rulestack;
struct rule	*parse_rule;

struct files	 parse_filestack;
struct file	*parse_file;

int		 yyparse(void);

int
parse_conf(const char *path, struct strings *macros)
{
	struct macro	*macro;
	FILE		*f;
	u_int		 i;

	if ((f = fopen(path, "r")) == NULL)
		return (-1);

	ARRAY_INIT(&parse_rulestack);
	parse_rule = NULL;

	ARRAY_INIT(&parse_filestack);
	parse_file = xmalloc(sizeof *parse_file);

	parse_file->f = f;
	parse_file->line = 0;
	parse_file->path = path;

	strb_create(&parse_tags);
	default_tags(&parse_tags, NULL);
	add_tag(&parse_tags, "home", "%s", conf.user_home);

	TAILQ_INIT(&parse_macros);
	parse_last = NULL;
	for (i = 0; i < ARRAY_LENGTH(macros); i++) {
		parse_last = extract_macro(ARRAY_ITEM(macros, i));
		TAILQ_INSERT_TAIL(&parse_macros, parse_last, entry);
	}

	parse_file->line++;
	yyparse();

	if (!ARRAY_EMPTY(&parse_rulestack))
		yyerror("missing }");
	ARRAY_FREE(&parse_rulestack);

	ARRAY_FREE(&parse_filestack);
	xfree(parse_file);

	while (!TAILQ_EMPTY(&parse_macros)) {
		macro = TAILQ_FIRST(&parse_macros);
		TAILQ_REMOVE(&parse_macros, macro, entry);

		if (macro->type == MACRO_STRING)
			xfree(macro->value.str);
		xfree(macro);
	}

	strb_destroy(&parse_tags);

	fclose(f);
	return (0);
}

__dead printflike1 void
yyerror(const char *fmt, ...)
{
	va_list	ap;
	char   *s;

	xasprintf(&s,
	    "%s: %s at line %d", parse_file->path, fmt, parse_file->line);

	va_start(ap, fmt);
	log_vwrite(LOG_CRIT, s, ap);
	va_end(ap);

	exit(1);
}
#ifdef YYSTYPE
#undef  YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
#ifndef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#line 255 "parse.y"
typedef union YYSTYPE
{
	long long		 number;
	char			*string;
	int			 flag;
	u_int			 locks;
	struct {
		struct fetch	*fetch;
		void		*data;
	} fetch;
	struct {
		char		*host;
		char		*port;
	} server;
	enum area		 area;
	enum exprop		 exprop;
	struct actitem		*actitem;
	struct actlist		*actlist;
	struct expr		*expr;
	struct expritem		*expritem;
	struct strings		*strings;
	struct replstrs		*replstrs;
	enum fetch_only		 only;
	struct {
		char		*path;
		enum fetch_only	 only;
	} poponly;
	struct {
		int		 flags;
		char		*str;
	} re;
	gid_t			 localgid;
	enum cmp		 cmp;
	struct rule		*rule;
	struct {
		char		*user;
		int		 user_netrc;
		char		*pass;
		int		 pass_netrc;
	} userpass;
	userfunction		 ufn;
	struct userfunctions	*ufns;
} YYSTYPE;
#endif /* !YYSTYPE_IS_DECLARED */
#line 176 "parse.c"

/* compatibility with bison */
#ifdef YYPARSE_PARAM
/* compatibility with FreeBSD */
# ifdef YYPARSE_PARAM_TYPE
#  define YYPARSE_DECL() yyparse(YYPARSE_PARAM_TYPE YYPARSE_PARAM)
# else
#  define YYPARSE_DECL() yyparse(void *YYPARSE_PARAM)
# endif
#else
# define YYPARSE_DECL() yyparse(void)
#endif

/* Parameters sent to lex. */
#ifdef YYLEX_PARAM
# define YYLEX_DECL() yylex(void *YYLEX_PARAM)
# define YYLEX yylex(YYLEX_PARAM)
#else
# define YYLEX_DECL() yylex(void)
# define YYLEX yylex()
#endif

#if !(defined(yylex) || defined(YYSTATE))
int YYLEX_DECL();
#endif

/* Parameters sent to yyerror. */
#ifndef YYERROR_DECL
#define YYERROR_DECL() yyerror(const char *s)
#endif
#ifndef YYERROR_CALL
#define YYERROR_CALL(msg) yyerror(msg)
#endif

extern int YYPARSE_DECL();

#define TOKACCOUNT 257
#define TOKACCOUNTS 258
#define TOKACTION 259
#define TOKACTIONS 260
#define TOKADDHEADER 261
#define TOKADDTOCACHE 262
#define TOKAGE 263
#define TOKALL 264
#define TOKALLOWMANY 265
#define TOKAND 266
#define TOKANYNAME 267
#define TOKANYSIZE 268
#define TOKANYTYPE 269
#define TOKAPPEND 270
#define TOKATTACHMENT 271
#define TOKBODY 272
#define TOKBYTES 273
#define TOKCACHE 274
#define TOKCASE 275
#define TOKCMDUSER 276
#define TOKCOMPRESS 277
#define TOKCONTINUE 278
#define TOKCOUNT 279
#define TOKDAYS 280
#define TOKDEFUSER 281
#define TOKDELTOOBIG 282
#define TOKDISABLED 283
#define TOKDOMAIN 284
#define TOKDOTLOCK 285
#define TOKDROP 286
#define TOKEQ 287
#define TOKEXEC 288
#define TOKEXPIRE 289
#define TOKFCNTL 290
#define TOKFILEGROUP 291
#define TOKFILEUMASK 292
#define TOKFLOCK 293
#define TOKFOLDER 294
#define TOKFOLDERS 295
#define TOKFROM 296
#define TOKGIGABYTES 297
#define TOKGROUP 298
#define TOKGROUPS 299
#define TOKHEADER 300
#define TOKHEADERS 301
#define TOKHOURS 302
#define TOKIGNOREERRORS 303
#define TOKIMAP 304
#define TOKIMAPS 305
#define TOKIMPLACT 306
#define TOKIN 307
#define TOKINCACHE 308
#define TOKINSECURE 309
#define TOKINVALID 310
#define TOKKEEP 311
#define TOKKEY 312
#define TOKKILOBYTES 313
#define TOKLMTP 314
#define TOKLOCKFILE 315
#define TOKLOCKTIMEOUT 316
#define TOKLOCKTYPES 317
#define TOKLOCKWAIT 318
#define TOKLOOKUPORDER 319
#define TOKMAILDIR 320
#define TOKMAILDIRS 321
#define TOKMATCH 322
#define TOKMATCHED 323
#define TOKMAXSIZE 324
#define TOKMBOX 325
#define TOKMBOXES 326
#define TOKMEGABYTES 327
#define TOKMINUTES 328
#define TOKMONTHS 329
#define TOKNE 330
#define TOKNEWONLY 331
#define TOKNNTP 332
#define TOKNNTPS 333
#define TOKNOAPOP 334
#define TOKNOCRAMMD5 335
#define TOKNOCREATE 336
#define TOKNOLOGIN 337
#define TOKNONE 338
#define TOKNOPLAIN 339
#define TOKNORECEIVED 340
#define TOKNOT 341
#define TOKNOUIDL 342
#define TOKNOVERIFY 343
#define TOKXOAUTH2 344
#define TOKOAUTHBEARER 345
#define TOKOLDONLY 346
#define TOKOR 347
#define TOKPARALLELACCOUNTS 348
#define TOKPASS 349
#define TOKPASSWD 350
#define TOKPIPE 351
#define TOKPOP3 352
#define TOKPOP3S 353
#define TOKPORT 354
#define TOKPROXY 355
#define TOKPURGEAFTER 356
#define TOKQUEUEHIGH 357
#define TOKQUEUELOW 358
#define TOKREMOVEFROMCACHE 359
#define TOKREMOVEHEADER 360
#define TOKREMOVEHEADERS 361
#define TOKRETURNS 362
#define TOKREWRITE 363
#define TOKSECONDS 364
#define TOKSERVER 365
#define TOKSET 366
#define TOKSIZE 367
#define TOKSMTP 368
#define TOKSTARTTLS 369
#define TOKSTDIN 370
#define TOKSTDOUT 371
#define TOKSTRING 372
#define TOKSTRIPCHARACTERS 373
#define TOKTAG 374
#define TOKTAGGED 375
#define TOKTIMEOUT 376
#define TOKTO 377
#define TOKTOTALSIZE 378
#define TOKUNMATCHED 379
#define TOKUSER 380
#define TOKUSERS 381
#define TOKVALUE 382
#define TOKVERIFYCERTS 383
#define TOKWEEKS 384
#define TOKWRITE 385
#define TOKYEARS 386
#define NONE 387
#define NUMBER 388
#define STRING 389
#define STRMACRO 390
#define NUMMACRO 391
#define STRCOMMAND 392
#define NUMCOMMAND 393
#define YYERRCODE 256
typedef int YYINT;
static const YYINT yylhs[] = {                           -1,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   82,
   82,   83,   83,   84,   84,   85,   85,   86,   86,   87,
   87,   88,   88,   89,   89,   59,   59,   60,   60,   55,
   55,   55,   56,   56,   37,   37,   37,   57,   58,   35,
   35,   35,   35,   35,   36,   36,   36,   36,   36,   36,
   36,   36,   39,   39,   81,   79,   79,   79,   79,   79,
   79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
   79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
   79,   79,   79,   77,   77,   43,   43,   63,   63,   64,
   64,   73,   74,   74,   45,   45,   65,   65,   66,   66,
   68,   68,   33,   33,   33,   34,   34,   34,   32,   32,
   62,   62,   47,   47,   47,   48,   48,   13,   13,   15,
   15,   14,   14,   52,   52,   51,   51,   53,   53,   54,
   54,   18,   18,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    2,   76,   76,   46,   46,   44,   44,   12,   12,
    3,    3,    3,    3,   38,   38,   49,   49,    5,    5,
    6,    6,    4,    4,   16,   16,   17,   17,   10,   10,
    9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
    9,    9,    9,    9,    9,    9,    9,    8,    8,    7,
    7,   50,   50,   50,   50,   80,   78,   69,   69,   61,
   61,   67,   67,   24,   24,   25,   25,   26,   26,   28,
   28,   27,   27,   29,   29,   30,   30,   31,   31,   19,
   19,   20,   20,   40,   40,   21,   21,   22,   22,   23,
   23,   72,   72,   72,   72,   71,   70,   70,   42,   42,
   41,   41,   11,   11,   11,   11,   11,   11,   11,   11,
   75,
};
static const YYINT yylen[] = {                            2,
    0,    2,    2,    2,    2,    2,    2,    2,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    2,    1,    2,    0,    1,
    1,    1,    1,    3,    1,    1,    1,    1,    1,    1,
    2,    2,    2,    2,    1,    2,    2,    2,    2,    2,
    2,    2,    2,    0,    3,    3,    3,    3,    2,    3,
    2,    2,    2,    3,    3,    3,    3,    3,    3,    3,
    3,    2,    3,    3,    3,    3,    2,    2,    3,    3,
    3,    3,    3,    3,    3,    2,    1,    2,    1,    2,
    1,    1,    2,    1,    2,    4,    2,    4,    2,    4,
    2,    4,    1,    1,    1,    2,    1,    1,    1,    1,
    0,    2,    0,    2,    4,    2,    1,    1,    0,    1,
    0,    1,    0,    2,    2,    3,    2,    0,    2,    0,
    2,    1,    0,    2,    2,    2,    2,    1,    3,    3,
   12,    4,    4,    1,    3,    4,    4,    1,    1,    1,
    2,    1,    4,    6,    2,    4,    2,    4,    0,    1,
    0,    2,    2,    2,    1,    0,    1,    0,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    3,    2,   10,    3,    4,    5,    5,    2,    2,
    4,    3,    5,    5,    5,    4,    4,    3,    2,    1,
    2,    4,    6,    3,    1,    1,    3,    0,    1,    0,
    2,    2,    4,    1,    0,    1,    0,    1,    0,    1,
    0,    1,    0,    1,    0,    1,    0,    1,    0,    1,
    0,    1,    0,    1,    1,    1,    1,    1,    1,    1,
    1,    4,    0,    2,    2,    4,    1,    0,    3,    0,
    1,    0,    9,    6,   13,    6,    1,    1,    1,    8,
    6,
};
static const YYINT yydefred[] = {                         1,
    0,    0,    0,    0,    0,    0,    9,    0,    0,  206,
    2,    3,    4,    5,    6,    7,    8,   31,   32,   30,
   33,    0,    0,    0,    0,    0,  118,    0,    0,    0,
   63,    0,    0,   61,    0,    0,   62,    0,    0,    0,
    0,   59,    0,    0,   78,   77,    0,    0,    0,    0,
    0,    0,    0,   72,    0,    0,    0,  122,    0,   12,
   13,    0,    0,    0,   55,  205,    0,  207,  179,  180,
    0,    0,   14,   15,    0,  181,    0,    0,  175,    0,
  189,  176,    0,    0,    0,  190,    0,  183,    0,  117,
    0,    0,    0,   79,   36,   37,   35,   80,  110,  109,
   81,   83,   74,   73,   58,   60,    0,  105,  103,  104,
  108,  107,    0,   92,   94,    0,   56,    0,   70,   71,
   76,   75,   68,   69,    0,   67,    0,   85,   34,    0,
   10,   11,    0,    0,  178,  149,  238,  239,  150,    0,
    0,    0,    0,   24,   25,    0,    0,  144,    0,  177,
    0,  153,    0,    0,    0,  148,  138,    0,    0,    0,
    0,   53,    0,    0,    0,  199,  192,  169,  170,    0,
    0,    0,    0,    0,    0,  116,    0,    0,    0,    0,
    0,    0,  182,    0,    0,   49,   46,   47,   51,   48,
   50,   52,  106,   93,   41,   44,   42,   43,    0,   20,
   21,   22,   23,  240,  241,    0,  237,  257,    0,    0,
    0,    0,  258,  259,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  152,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  160,  204,    0,
    0,  198,  191,    0,    0,    0,  171,  172,    0,  173,
  174,    0,    0,  186,    0,    0,    0,  162,  164,  163,
    0,    0,    0,  120,  261,    0,    0,    0,    0,   97,
    0,   99,    0,    0,  139,    0,    0,    0,    0,  132,
  140,    0,    0,    0,  145,  154,  151,    0,    0,    0,
    0,    0,  115,    0,    0,  202,  195,  193,  194,    0,
  187,    0,    0,  156,    0,    0,    0,    0,    0,   91,
    0,    0,    0,    0,    0,  126,    0,    0,  143,    0,
  142,    0,  245,    0,   18,   19,    0,    0,  158,   96,
    0,    0,    0,    0,  247,    0,  234,  235,    0,    0,
  209,    0,    0,   16,   17,    0,    0,   98,   90,  100,
  125,  124,    0,    0,  230,    0,    0,  203,  165,    0,
    0,    0,    0,    0,  232,    0,  251,    0,    0,  101,
    0,    0,  212,  242,  214,    0,    0,    0,  256,  254,
  249,    0,    0,   89,    0,    0,    0,  216,    0,  167,
    0,  246,  222,    0,    0,  102,   88,    0,  213,  218,
    0,  184,  220,    0,    0,  224,  260,    0,  253,    0,
    0,    0,  226,    0,    0,  228,  141,    0,  255,
};
#if defined(YYDESTRUCT_CALL) || defined(YYSTYPE_TOSTRING)
static const YYINT yystos[] = {                           0,
  395,  257,  259,  274,  322,  366,  387,  390,  391,  125,
  470,  471,  472,  473,  474,  475,  476,  389,  390,  392,
  450,  451,  452,  452,  451,  453,  341,  402,  404,  408,
  265,  276,  281,  282,  291,  292,  303,  306,  315,  316,
  317,  318,  319,  324,  336,  340,  348,  355,  356,  357,
  358,  373,  376,  383,   61,   61,   43,  283,  409,  380,
  381,  442,  478,  289,  434,  123,  442,  445,  266,  347,
  403,  405,  257,  258,  263,  264,  271,  275,  288,  308,
  323,  351,  367,  372,  375,  379,  411,  441,  443,  452,
  479,  451,  451,  380,  388,  391,  393,  427,  432,  452,
  380,  432,  286,  311,  453,  431,  432,  285,  290,  293,
  338,  428,  429,  350,  468,  469,  430,  432,  432,  452,
  338,  432,  432,  432,  451,  431,  451,  432,  450,  442,
  259,  260,  261,  262,  270,  286,  304,  305,  311,  314,
  320,  325,  359,  360,  361,  363,  368,  371,  374,  385,
  123,  396,  411,  412,  417,  439,  440,  477,  484,  123,
  451,  431,  439,  477,  405,  404,  310,   60,   62,  400,
  267,  268,  269,  279,  378,  452,  453,  400,  451,  451,
  451,  307,  398,  123,  451,  280,  302,  328,  329,  364,
  384,  386,  428,  468,  273,  297,  313,  327,  304,  320,
  321,  325,  326,  332,  333,  352,  353,  370,  406,  416,
  417,  418,  460,  461,  482,  483,  451,  453,  365,  446,
  451,  451,  453,  451,  446,  451,  396,  397,  451,  451,
  446,  123,  451,  123,  451,  438,  451,  278,  407,  123,
  396,  404,  431,  451,  400,  451,  287,  330,  399,  400,
  401,  400,  312,  430,  377,  380,  457,  264,  272,  301,
  438,  351,  351,  311,  410,  446,  446,  446,  123,  453,
  123,  453,  382,  451,  454,  312,  452,  296,  449,  277,
  413,  312,  449,  382,  455,  125,  396,  349,  380,  467,
  438,  438,  125,  451,  397,  407,  430,  432,  430,  451,
  443,  451,  362,  125,  452,  452,  467,  467,  467,  453,
  459,  459,  451,  451,  354,  447,  451,  377,  448,  451,
  448,  451,  452,  452,  294,  295,  456,  481,  125,  125,
  125,   40,  380,  465,  466,  466,  331,  346,  435,  437,
  463,  464,  481,  298,  299,  462,  480,  125,  453,  125,
  432,  452,  451,  349,  343,  414,  451,  407,  432,  433,
  452,  464,  437,  274,  334,  415,  435,  436,  123,  452,
  274,  123,  452,  452,  335,  419,   44,  349,  436,  415,
  453,  414,  414,  452,  458,  453,  458,  339,  420,  443,
  444,  452,  342,  422,  419,  125,  452,  414,  125,  337,
  421,   41,  369,  423,  420,  309,  424,  423,  424,  421,
  424,  423,  345,  425,  424,  344,  426,  425,  426,
};
#endif /* YYDESTRUCT_CALL || YYSTYPE_TOSTRING */
static const YYINT yydgoto[] = {                          1,
  227,  228,  183,  249,  170,  251,   28,   71,   29,   72,
  209,  239,   30,   59,  265,  153,  154,  281,  356,  366,
  210,  155,  212,  376,  389,  401,  394,  404,  407,  414,
  417,   98,  112,  113,  117,  106,  107,  360,   65,  339,
  368,  340,  291,  156,  157,   88,   62,   89,  391,   68,
  220,  316,  319,  279,   21,   22,   90,  310,  275,  285,
  327,  257,  385,  311,  213,  214,  346,  341,  342,  334,
  335,  290,  115,  116,   11,   12,   13,   14,   15,   16,
   17,  158,   63,   91,  347,  343,  215,  216,  159,
};
static const YYINT yysindex[] = {                         0,
  715, -304, -304, -304, -252, 4601,    0,   31,   48,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   73, -138, -314,   73, -171,    0, -107, -243, -180,
    0, -304, -304,    0,  704, -213,    0, -246, -304, -242,
 -244,    0, -197, -242,    0,    0, -242, -304, -320, -242,
 -242, -304, -242,    0, -304, -242, -304,    0, -314,    0,
    0, 4202, -120, -242,    0,    0, -184,    0,    0,    0,
 -243, -252,    0,    0,  -32,    0, -234, -304,    0, -304,
    0,    0,   -7, -304, -304,    0, -304,    0, -152,    0,
  -99,   73,   73,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, -265,    0,    0,    0,
    0,    0, -160,    0,    0, -197,    0, -215,    0,    0,
    0,    0,    0,    0,   73,    0,   73,    0,    0, 1359,
    0,    0, -304, -304,    0,    0,    0,    0,    0, -200,
 -304, -304, -304,    0,    0, -304, -200,    0, -304,    0,
 4538,    0, -304, -304, -200,    0,    0,  -72,    8, -304,
   73,    0, -110, 4040, -252,    0,    0,    0,    0, -242,
 -304,   -7, -304,  -53,   -7,    0, -143, -242,  -35,   73,
  -43, -220,    0, -304,   73,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, -179,    0,
    0,    0,    0,    0,    0, -178,    0,    0, -137, -200,
 -200, -200,    0,    0,   15,   38,   -5, -136, -304, -117,
   73,  -39, -131,   73, -117,  -41,    0, 4332,   73,   73,
 -306, -304,   73, -304,   73,   25,   73,    0,    0, 4470,
 -110,    0,    0,   73, -242,   73,    0,    0, -242,    0,
    0, -242, -304,    0, -253, -304, -176,    0,    0,    0,
   60, -304, -304,    0,    0, -306, -306, -306, -304,    0,
 -304,    0, -304,   73,    0, -304, -170, -304, -194,    0,
    0, -304, -194, -304,    0,    0,    0, -304, -304, -154,
   64,   83,    0,   73, 4408,    0,    0,    0,    0,   73,
    0,   73,  148,    0, -189, -189, -277, -154, -164,    0,
   91,  118,   73,   73,  396,    0,   73, -304,    0,   73,
    0,   73,    0, -155,    0,    0, -147, -304,    0,    0,
 -110, -242, -304, -154,    0, -277,    0,    0,  -77, -133,
    0, -277,   43,    0,    0,  -76,   47,    0,    0,    0,
    0,    0,   73, -304,    0, -132,   73,    0,    0,  158,
 -145, -277, -133, -304,    0, -147,    0, -147, -304,    0,
 -304, -304,    0,    0,    0, -134, -253, -304,    0,    0,
    0, -129, -132,    0,  123, -147,  129,    0, -130,    0,
  176,    0,    0, -149, -134,    0,    0,  -88,    0,    0,
 -149,    0,    0,  -88, -130,    0,    0,  -88,    0, -149,
 -122,  -88,    0, -118, -122,    0,    0, -118,    0,
};
static const YYINT yyrindex[] = {                         0,
    0,    0,    0,    0, -161,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    1, 3850, 4264,  100,   29,    0, -100,  359,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1454,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  370, -161,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  612,    0,
    0,  873, 3485,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1329,    0,    0,    0,
    0,    0, 3687,    0,    0, 3705,    0, 3115,    0,    0,
    0,    0,    0,    0, 3724,    0, 3737,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 4134,    0, 3743,    0, -161,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  901,
 -127,    0,    0,    0,  967,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, -141,    0,
    0,    0,    0,    0,    0, -126,    0,    0, 3757,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1477,
 1762, 1857,    0, 1952, 1477, 2047,    0,    0, 2142, 2237,
  458,    0, 2332,    0, 2427,    0,  134,    0,    0,    0,
 3743,    0,    0, 1085,    0, 1204,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3407, 3286, -135,    0,    0,
    0,    0,    0, 2522,    0,    0,  200,    0, 2617,    0,
    0,    0, 2617,    0,    0,    0,    0,    0,    0,  576,
    0,    0,    0,  140,    0,    0,    0,    0,    0, 1233,
    0, -125,    0,    0,  994,    0, 3474, 3305,    0,    0,
    0,    0, 2712, 2807,    0,    0, 1572,    0,    0, 2902,
    0, 2997,    0,  339,    0,    0,  813,    0,    0,    0,
 3743,  183,    0,  468,    0,  281,    0,    0,    0, 3544,
    0, 3345,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3092,    0,    0,  932,  695,    0,    0,    0,
    0,  738,  754,    0,    0, 3638,    0, 3445,    0,    0,
    0,    0,    0,    0,    0, 1050,  189,    0,    0,    0,
    0,  501,   57,    0,    0,  975,    0,    0, 1169,    0,
    0,    0,    0, 3679, 3536,    0,    0, 1131,    0,    0,
 1287,    0,    0, 1131, 3585,    0,    0, 1382,    0, 3647,
 1667,  657,    0, 3187,  517,    0,    0, 1228,    0,
};
#if YYBTYACC
static const YYINT yycindex[] = {                         0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,
};
#endif
static const YYINT yygindex[] = {                         0,
  -51,   -8,    0,    0,  -52,    0,    0,    0,  -60,  162,
    0, -202,    0,    0,    0,  206,    0,    0, -296, -123,
    0,  111,    0, -119, -153, -159,    0, -351, -297, -166,
 -173,    0,  137,    0, -165,  -28,  -30,    0,    0, -315,
 -111,  -84, -128,  186,    0,    0,   20, -245,    0,    0,
  -54,    0,  -26,   30,  209, 4106, 3889,  113,    0,    0,
    0,    0, -104,    5,    0,    0,    0,    0,  -42,    0,
  -24, -206,  164,    0,    0,    0,    0,    0,    0,    0,
    0,  216,    0,    0,    0,    4,    0,    0,    0,
};
#define YYTABLESIZE 4984
static const YYINT yytable[] = {                         57,
   38,   57,  160,   57,   99,  102,  168,   57,  169,  301,
  152,  166,  254,  118,  186,   66,  119,  121,  122,  123,
  124,   78,   69,  184,  126,  128,  367,  168,   54,  169,
  178,  236,  171,  172,  173,  162,  187,   57,  296,  103,
  108,   38,  288,  258,  174,  109,  367,   67,  110,  408,
  232,  259,  168,  337,  169,  261,  215,  195,  412,  307,
  308,  309,  188,  189,  104,   60,   61,   95,  338,  382,
   96,  383,   97,  289,  131,  132,   73,   74,  130,  297,
  260,  196,   75,   76,   18,   19,  299,   20,   27,  398,
   77,   55,  225,  111,   78,  119,  119,  197,  190,   39,
  231,  119,  119,   70,  242,  292,  409,   79,   56,  119,
  411,  198,  241,  119,  415,   57,   26,   64,  191,  245,
  192,  250,  252,   38,  108,   38,  119,   80,  358,  109,
  234,  390,  110,  344,  345,   18,   19,  269,   20,  325,
  326,  243,   81,  175,   58,   95,  119,  118,   96,  293,
   97,  105,  114,   54,  182,  266,  267,  268,  113,  113,
  271,  119,  243,  243,  219,  369,  101,  238,  253,  372,
   82,  262,  263,  264,   95,  276,  287,   96,  278,   97,
  282,  215,  318,  315,  304,  303,   83,  332,  329,  119,
  333,   84,  177,  354,   85,  355,  364,  371,   86,  127,
  365,  377,  375,  378,  388,  119,  400,  330,   18,   19,
  119,   20,  393,  119,  118,  348,  402,  119,  298,  403,
  406,  118,  413,  238,   39,  416,  166,  119,  119,  168,
  119,  295,  165,  247,  111,   87,  112,  280,  236,  380,
  211,  405,  350,  287,  419,  410,  218,  396,  418,  193,
  379,  363,  163,  399,  283,  223,  321,   38,   87,   38,
   38,   38,   38,  395,   86,  129,   38,  387,   18,   19,
   38,   20,   60,   61,   38,  312,  248,  167,   38,  194,
  250,  336,  164,   38,  351,   54,   38,   54,   38,   18,
   19,  362,   20,  328,   38,   38,   38,    0,   38,   38,
    0,  359,   54,    0,   38,   38,    0,   38,    0,   38,
    0,   38,    0,  215,   38,  215,   18,   19,    0,   20,
   38,   38,   38,    0,  127,   38,   38,  270,  272,    0,
  215,   38,   38,   38,   38,   38,  256,   38,  244,   38,
  284,  255,   38,   38,   38,   38,   38,   38,    0,   38,
   54,   38,   38,   38,   38,    0,   39,    0,   39,   38,
   38,   38,    0,   38,    0,  215,   38,  215,   38,   38,
   38,   38,    0,   39,   38,    0,  273,   38,  215,    0,
   38,   38,    0,   18,   19,   38,   20,   38,   39,   38,
   38,   38,   38,  215,   54,  215,   18,   19,    0,   20,
  215,  215,    0,   18,   19,  250,   20,    0,   39,    0,
   39,   39,    0,   18,   19,   54,   20,    0,   54,   54,
    0,   39,  215,  349,  349,  215,   18,   19,    0,   20,
    0,   18,   19,   39,   20,   18,   19,    0,   20,    0,
    0,   39,   39,  215,    0,    0,  215,  215,   18,   19,
    0,   20,   18,   19,    0,   20,  127,  243,  127,  127,
  127,  127,    0,  244,    0,   39,    0,  208,   39,  127,
    0,   18,   19,  127,   20,    0,  381,  127,    0,   18,
   19,  200,   20,  386,    0,  127,   39,  127,   39,   39,
   39,   39,  201,  127,  127,  127,    0,  127,  127,    0,
  223,    0,    0,  127,  127,    0,   18,   19,  127,   20,
  127,   18,   19,  127,   20,    0,  227,   18,   19,  127,
   20,  127,   87,   87,  127,   87,    0,    0,   86,   86,
  127,   86,    0,  127,  127,    0,  127,  250,  127,  250,
    0,  127,  127,  127,  127,  127,    0,    0,  127,    0,
  127,    0,    0,    0,  250,    0,    0,    0,  127,  127,
  127,    0,  127,    0,    0,  127,    0,  127,  127,    0,
  127,    0,    0,  127,    0,  210,  127,    0,    0,  127,
    0,    0,  243,    0,  127,    0,  127,    0,    0,  127,
  127,  250,  208,    0,    0,  244,    0,  244,  244,  244,
  244,    0,  250,    0,    0,    0,    0,    0,  244,    0,
    0,    0,  244,    0,  250,    0,  244,  200,  200,    0,
    0,    0,    0,    0,  244,  223,  244,    0,  201,  201,
    0,    0,  244,  244,    0,    0,  244,  244,    0,    0,
    0,  227,  244,  244,    0,    0,  250,  244,    0,  244,
    0,    0,  244,    0,    0,    0,  225,    0,  244,    0,
  244,    0,    0,  244,    0,    0,    0,  250,    0,  244,
  250,  250,  244,  244,    0,  244,    0,  244,    0,    0,
  244,  244,  244,  244,  244,    0,    0,    0,    0,  244,
    0,    0,    0,    0,  211,    0,    0,  244,  244,  244,
  210,  244,    0,    0,  244,    0,  244,  244,    0,  244,
    0,    0,  244,    0,  243,    0,  243,  243,  243,  243,
    0,    0,    0,  244,  208,  244,  208,  243,  244,  244,
    0,  243,    0,    0,  161,  243,    0,  252,  200,  200,
    0,  208,    0,  243,    0,  243,    0,    0,    0,  201,
  201,  243,  243,  233,    0,    0,    0,  223,    0,  223,
    0,  243,  243,    0,    0,    0,  243,    0,  243,    0,
    0,  243,    0,  227,  223,  227,    0,  243,  208,  243,
    0,  225,  243,   95,   18,   19,   96,   20,   97,  208,
  227,    0,  243,    0,  243,    0,  243,    0,  208,    0,
  243,  243,  243,    0,    0,    0,    0,    0,  243,  223,
    0,  223,  231,  208,    0,    0,  243,  243,  243,  211,
  243,    0,  223,  243,    0,  243,  243,  227,  243,    0,
    0,  243,  210,  208,  210,  210,  210,  210,  227,   10,
    0,    0,  243,    0,  243,  210,    0,  243,  243,  210,
    0,    0,    0,  210,  208,    0,    0,  208,  208,    0,
  227,  210,  252,  210,    0,    0,  223,    0,    0,  223,
  161,  161,   65,    0,    0,    0,    0,  161,  233,  210,
  210,    0,  227,    0,  210,    0,  210,  223,    0,  210,
  223,  223,    0,    0,    0,  210,    0,  210,    0,    0,
  210,    0,    0,  227,    0,    0,  227,  227,    0,    0,
  210,    0,  210,  225,  210,  225,    0,    0,  210,  210,
  210,    0,    0,    0,    0,    0,  210,    0,    0,    0,
  225,  215,    0,    0,  210,  210,  210,  231,  210,    0,
    0,  210,    0,  210,  210,    0,  210,    0,    0,  210,
    0,  211,    0,  211,  211,  211,  211,    0,  161,    0,
  210,    0,  210,    0,  211,  210,  210,  225,  211,    0,
    0,    2,  211,    3,  231,    0,    0,    0,  225,    0,
  211,    0,  211,    0,    0,    0,    0,    0,    4,    0,
    0,  161,  161,  248,  252,    0,  252,   65,  211,  211,
  225,  225,    0,  211,    0,  211,    0,    0,  211,    0,
  233,  252,  233,    0,  211,    0,  211,    0,    0,  211,
    0,    0,  225,  185,    0,    0,    0,  233,    0,  211,
    0,  211,    0,  211,    0,    0,    5,  211,  211,  211,
    0,    0,    0,  225,    0,  211,  225,  225,  252,  217,
    0,    0,    0,  211,  211,  211,  215,  211,    0,  252,
  211,    0,  211,  211,  233,  211,    0,    0,  211,  231,
    0,  231,  231,  231,  231,  233,    0,    0,    0,  211,
    6,  211,  231,   94,  211,  211,  231,    0,    0,  155,
  231,   95,   18,   19,   96,   20,   97,    0,  231,  231,
  231,    7,    0,  252,    8,    9,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  231,  231,  248,  233,
    0,  231,    0,  231,  252,    0,  231,  252,  252,   65,
  225,   65,  231,    0,  231,    0,    0,  231,    0,    0,
  233,    0,    0,  233,  233,    0,   65,  231,    0,  231,
    0,  231,    0,    0,    0,    0,  231,  231,    0,  185,
  185,    0,    0,  231,    0,    0,  185,    0,  219,    0,
    0,  231,  231,  231,  217,  231,    0,    0,  231,    0,
  231,  231,    0,  231,    0,    0,  231,    0,  215,    0,
  215,  215,  215,  215,   65,    0,    0,  231,    0,  231,
    0,  215,  231,  231,    0,  215,    0,  197,    0,  215,
    0,    0,    0,    0,    0,    0,    0,  215,    0,  215,
    0,    0,    0,    0,    0,  155,  155,  229,    0,    0,
    0,  231,  155,  231,    0,  215,  215,    0,   65,    0,
  215,    0,  215,    0,    0,  215,    0,  185,  231,    0,
  248,  215,  248,  215,    0,  225,  215,    0,    0,   65,
    0,    0,   65,   65,    0,    0,    0,  248,  215,    0,
  215,    0,    0,    0,    0,  215,  215,    0,    0,    0,
  185,  185,  215,  231,    0,  231,  221,  248,  248,    0,
  215,  215,  215,  219,  215,    0,  231,  215,    0,  215,
  215,    0,  215,    0,  248,  215,  217,    0,  217,  217,
  217,  217,    0,  155,    0,  248,  215,    0,  215,  217,
    0,  215,  215,  217,  248,    0,  196,  217,   45,    0,
    0,    0,    0,    0,    0,  217,    0,  217,    0,  248,
  231,    0,    0,  197,  197,    0,  155,  155,    0,    0,
  197,    0,  229,  217,  217,  188,    0,    0,  217,  248,
  217,  231,    0,  217,  231,  231,    0,    0,    0,  217,
    0,  217,    0,    0,  217,    0,    0,    0,    0,    0,
  248,  225,    0,  248,  248,    0,  217,  225,    0,  225,
    0,    0,    0,  217,  217,    0,    0,    0,    0,    0,
  217,    0,    0,    0,  225,    0,    0,    0,  217,  217,
  217,  221,  217,    0,    0,  217,    0,  217,  217,    0,
  217,    0,    0,  217,    0,  219,    0,  219,  219,  219,
  219,  197,    0,    0,  217,    0,  217,    0,  219,  217,
  217,  225,  219,    0,    0,    0,  219,    0,    0,    0,
    0,   45,  225,   45,  219,    0,  219,    0,    0,    0,
    0,    0,  196,  196,  197,  197,    0,    0,    0,  196,
    0,    0,  219,  219,    0,    0,  130,  219,    0,  219,
    0,    0,  219,    0,  229,    0,  229,    0,  219,    0,
  219,  188,  188,  219,    0,    0,  225,    0,  188,    0,
    0,  229,    0,    0,    0,    0,  225,    0,    0,    0,
    0,    0,  219,  219,    0,    0,    0,  225,    0,  219,
  225,  225,    0,    0,    0,    0,    0,  219,  219,  219,
    0,  219,    0,    0,  219,    0,  219,  219,  229,  219,
    0,    0,  219,  221,    0,  221,  221,  221,  221,  229,
  196,    0,    0,  219,    0,  219,  221,    0,  219,  219,
  221,    0,    0,    0,  221,    0,    0,    0,    0,    0,
    0,  131,  221,    0,  221,    0,    0,    0,    0,  188,
    0,    0,    0,  196,  196,   45,    0,   45,   45,    0,
  221,  221,    0,  229,   45,  221,    0,  221,    0,    0,
  221,  130,   45,    0,    0,    0,  221,    0,  221,    0,
    0,  221,  188,  188,  229,    0,    0,  229,  229,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  221,  221,    0,    0,    0,    0,    0,  221,  225,    0,
  225,  225,  225,  225,    0,  221,  221,  221,    0,  221,
   45,  225,  221,    0,  221,  225,    0,  221,    0,  225,
  221,    0,  199,  138,    0,    0,  227,  225,    0,  225,
    0,  221,    0,  221,    0,   45,  221,  221,  200,  201,
    0,    0,    0,  202,  203,  225,  225,    0,    0,    0,
  204,  205,  225,    0,   45,  225,  131,    0,    0,    0,
    0,  225,    0,  225,    0,    0,  225,    0,   45,   45,
  206,  207,    0,    0,    0,   45,    0,    0,   45,   45,
    0,    0,    0,    0,    0,  225,  225,    0,  208,    0,
    0,    0,  225,  130,    0,  130,  130,  130,  130,    0,
  225,  225,  225,    0,  225,    0,  130,  225,    0,  225,
  130,    0,  225,    0,  130,  225,    0,  113,  113,    0,
    0,  137,  130,    0,  130,    0,  225,    0,  225,    0,
    0,  225,  225,  113,  113,    0,    0,    0,  113,  113,
  130,  130,    0,    0,    0,  113,  113,  130,    0,    0,
  130,  227,    0,    0,    0,    0,  130,    0,  130,    0,
    0,  130,    0,    0,    0,  113,  113,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  113,    0,    0,    0,  130,  131,    0,
  131,  131,  131,  131,    0,  130,  130,  130,    0,  130,
    0,  131,  130,    0,  130,  131,    0,  130,    0,  131,
  130,    0,    0,  130,    0,    0,  133,  131,    0,  131,
    0,  130,    0,  130,    0,    0,  130,  130,    0,    0,
    0,    0,    0,    0,    0,  131,  131,    0,    0,    0,
    0,    0,  131,    0,    0,  131,  137,    0,    0,    0,
    0,  131,    0,  131,    0,    0,  131,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  131,  227,    0,  227,  227,  227,  227,    0,
  131,  131,  131,    0,  131,    0,  227,  131,    0,  131,
  227,    0,  131,    0,  227,  131,    0,    0,  131,    0,
    0,  135,  227,    0,  227,    0,  131,    0,  131,    0,
    0,  131,  131,    0,    0,    0,    0,    0,    0,    0,
  227,  227,    0,    0,    0,    0,    0,  227,    0,    0,
  227,  133,    0,    0,    0,    0,  227,    0,  227,    0,
    0,  227,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  227,    0,    0,    0,    0,    0,    0,  227,  137,    0,
  137,  137,  137,  137,    0,  227,  227,  227,    0,  227,
    0,  137,  227,    0,  227,  137,    0,  227,    0,  137,
  227,    0,    0,    0,    0,    0,   29,  137,    0,  137,
    0,  227,    0,  227,    0,    0,  227,  227,    0,    0,
    0,    0,    0,    0,    0,  137,  137,    0,    0,    0,
    0,    0,  137,    0,    0,  137,  135,    0,    0,    0,
    0,  137,    0,  137,    0,    0,  137,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  137,  133,    0,  133,  133,  133,  133,    0,
  137,  137,  137,    0,  137,    0,  133,  137,    0,  137,
  133,    0,  137,    0,  133,  137,    0,    0,    0,    0,
    0,  134,  133,    0,  133,    0,  137,    0,  137,    0,
    0,  137,  137,    0,    0,    0,    0,    0,    0,    0,
  133,  133,    0,    0,    0,    0,    0,  133,    0,    0,
  133,   29,    0,    0,    0,    0,  133,    0,  133,    0,
    0,  133,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  133,  135,    0,
  135,  135,  135,  135,    0,  133,  133,  133,    0,  133,
    0,  135,  133,    0,  133,  135,    0,  133,    0,  135,
  133,    0,    0,    0,    0,    0,  136,  135,    0,  135,
    0,  133,    0,  133,    0,    0,  133,  133,    0,    0,
    0,    0,    0,    0,    0,  135,  135,    0,    0,    0,
    0,    0,  135,    0,    0,  135,  134,    0,    0,    0,
    0,  135,    0,  135,    0,    0,  135,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  135,   29,    0,   29,   29,   29,   29,    0,
  135,  135,  135,    0,  135,    0,   29,  135,    0,  135,
   29,    0,  135,    0,   29,  135,    0,    0,    0,    0,
    0,  157,   29,    0,   29,    0,  135,    0,  135,    0,
    0,  135,  135,    0,    0,    0,    0,    0,    0,    0,
   29,   29,    0,    0,    0,    0,    0,   29,    0,    0,
   29,  136,    0,    0,    0,    0,   29,    0,   29,    0,
    0,   29,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   29,  134,    0,
  134,  134,  134,  134,    0,   29,   29,   29,    0,   29,
    0,  134,   29,    0,   29,  134,    0,   29,    0,  134,
   29,    0,    0,    0,    0,    0,   95,  134,    0,  134,
    0,   29,    0,   29,    0,    0,   29,   29,    0,    0,
    0,    0,    0,    0,    0,  134,  134,    0,    0,    0,
    0,    0,  134,    0,    0,  134,  157,    0,    0,    0,
    0,  134,    0,  134,    0,    0,  134,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  134,  136,    0,  136,  136,  136,  136,    0,
  134,  134,  134,    0,  134,    0,  136,  134,    0,  134,
  136,    0,  134,    0,  136,  134,    0,    0,    0,    0,
    0,   27,  136,    0,  136,    0,  134,    0,  134,    0,
    0,  134,  134,    0,    0,    0,    0,    0,    0,    0,
  136,  136,    0,    0,    0,    0,    0,  136,    0,    0,
  136,   95,    0,    0,    0,    0,  136,    0,  136,    0,
    0,  136,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  136,  157,    0,
  157,  157,  157,  157,    0,  136,  136,  136,    0,  136,
    0,  157,  136,    0,  136,  157,    0,  136,    0,  157,
  136,    0,    0,    0,    0,    0,  128,  157,    0,  157,
    0,  136,    0,  136,    0,    0,  136,  136,    0,    0,
    0,    0,    0,    0,    0,  157,  157,    0,    0,    0,
    0,    0,  157,    0,    0,  157,   27,    0,    0,    0,
    0,  157,    0,  157,    0,    0,  157,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  157,   95,    0,   95,   95,   95,   95,    0,
  157,  157,  157,    0,  157,    0,   95,  157,    0,  157,
   95,    0,  157,    0,   95,  157,    0,    0,    0,    0,
    0,   26,   95,    0,   95,    0,  157,    0,  157,    0,
    0,  157,  157,    0,    0,    0,    0,    0,    0,    0,
   95,   95,    0,    0,    0,    0,    0,   95,    0,    0,
   95,  128,    0,    0,    0,    0,   95,    0,   95,    0,
    0,   95,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   95,   27,    0,
   27,   27,   27,   27,    0,   95,   95,   95,    0,   95,
    0,   27,   95,    0,   95,   27,    0,   95,    0,   27,
   95,    0,    0,    0,    0,    0,  146,   27,    0,   27,
    0,   95,    0,   95,    0,    0,   95,   95,    0,    0,
    0,    0,    0,    0,    0,   27,   27,    0,    0,    0,
    0,    0,   27,    0,    0,   27,   26,    0,    0,    0,
    0,   27,    0,   27,    0,    0,   27,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   27,  128,    0,  128,  128,  128,  128,    0,
   27,   27,   27,    0,   27,    0,  128,   27,    0,   27,
  128,    0,   27,    0,  128,   27,    0,    0,    0,    0,
    0,  147,  128,    0,  128,    0,   27,    0,   27,    0,
    0,   27,   27,    0,    0,    0,    0,    0,    0,    0,
  128,  128,    0,    0,    0,    0,    0,  128,    0,    0,
  128,  146,    0,    0,    0,    0,  128,    0,  128,    0,
    0,  128,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  128,   26,    0,
   26,   26,   26,   26,    0,  128,  128,  128,    0,  128,
    0,   26,  128,    0,  128,   26,    0,  128,    0,   26,
  128,    0,    0,    0,    0,    0,   28,   26,    0,   26,
    0,  128,    0,  128,    0,    0,  128,  128,    0,    0,
    0,    0,    0,    0,    0,   26,   26,    0,    0,    0,
    0,    0,   26,    0,    0,   26,  147,    0,    0,    0,
    0,   26,    0,   26,    0,    0,   26,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   26,  146,    0,  146,  146,  146,  146,    0,
   26,   26,   26,    0,   26,    0,  146,   26,    0,   26,
  146,    0,   26,    0,  146,   26,    0,    0,    0,    0,
    0,  129,  146,    0,  146,    0,   26,    0,   26,    0,
    0,   26,   26,    0,    0,    0,    0,    0,    0,    0,
  146,  146,    0,    0,   40,    0,    0,  146,    0,    0,
  146,   28,    0,    0,    0,    0,  146,    0,  146,    0,
    0,  146,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  146,  147,    0,
  147,  147,  147,  147,    0,  146,  146,  146,    0,  146,
    0,  147,  146,    0,  146,  147,    0,  146,    0,  147,
  146,    0,    0,    0,    0,    0,  229,  147,    0,  147,
    0,  146,    0,  146,    0,    0,  146,  146,    0,    0,
    0,    0,    0,    0,    0,  147,  147,    0,    0,    0,
    0,    0,  147,    0,    0,  147,  129,    0,    0,    0,
    0,  147,    0,  147,    0,    0,  147,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   40,    0,   40,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  147,   28,    0,   28,   28,   28,   28,    0,
  147,  147,  147,    0,  147,    0,   28,  147,    0,  147,
   28,    0,  147,    0,   28,  147,    0,    0,    0,    0,
    0,    0,   28,    0,   28,  243,  147,    0,  147,    0,
    0,  147,  147,    0,    0,    0,    0,    0,    0,    0,
   28,   28,    0,    0,  208,    0,    0,   28,    0,    0,
   28,  229,    0,    0,    0,    0,   28,    0,   28,    0,
    0,   28,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  252,    0,    0,   28,  129,    0,
  129,  129,  129,  129,    0,   28,   28,   28,    0,   28,
    0,  129,   28,    0,   28,  129,    0,   28,    0,  129,
   28,   40,    0,   40,   40,    0,    0,  129,    0,  129,
   40,   28,    0,   28,    0,    0,   28,   28,   40,    0,
    0,    0,    0,    0,    0,  129,  129,    0,    0,    0,
    0,    0,  129,    0,    0,  129,  243,    0,    0,    0,
  243,  129,    0,  129,    0,    0,  129,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  208,
    0,    0,    0,    0,    0,    0,   40,    0,    0,    0,
    0,    0,  129,  229,  231,  229,  229,  229,  229,    0,
  129,  129,  129,    0,  129,    0,  229,  129,    0,  129,
  229,   40,  129,    0,  229,  129,    0,    0,    0,  252,
    0,    0,  229,  250,  229,    0,  129,    0,  129,    0,
   40,  129,  129,    0,   64,    0,    0,    0,    0,    0,
  229,  229,    0,    0,   40,   40,    0,  229,    0,    0,
  229,   40,    0,    0,   40,   40,  229,    0,  229,    0,
    0,  229,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  243,    0,    0,    0,  217,    0,  229,    0,    0,
    0,    0,  243,  233,  243,  229,  229,  229,    0,  229,
    0,    0,  229,    0,  229,    0,    0,  229,    0,  243,
  229,  208,    0,  208,    0,    0,    0,    0,    0,  231,
    0,  229,    0,  229,    0,    0,  229,  229,  208,  243,
  243,    0,    0,    0,  219,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  243,    0,  243,    0,  250,    0,
    0,  252,    0,  252,    0,    0,    0,  243,    0,   64,
    0,    0,    0,  208,    0,  208,  243,    0,  252,    0,
  243,    0,  243,    0,  243,    0,  208,    0,  243,  243,
  243,  243,    0,    0,    0,  208,    0,  231,    0,  208,
    0,  208,    0,  208,    0,    0,  221,  208,  208,  208,
  208,  243,    0,  252,  243,  252,    0,    0,    0,    0,
  217,    0,    0,  243,    0,  243,  252,    0,  233,    0,
  208,    0,  243,  208,    0,  243,  243,    0,  221,  252,
  243,  252,    0,  252,    0,    0,   57,  252,  252,  252,
    0,  208,    0,    0,  208,  208,    0,    0,    0,    0,
    0,  231,    0,  231,   82,    0,    0,    0,    0,  219,
  252,    0,    0,  252,    0,  243,    0,  243,  231,    0,
    0,    0,    0,   66,    0,    0,    0,    0,  243,    0,
  250,  252,  250,    0,  252,  252,   84,  243,    0,    0,
  243,   64,  159,   64,    0,    0,    0,  250,  243,  243,
    0,    0,  243,  231,    0,  231,  121,    0,   64,    0,
    0,    0,  231,    0,    0,    0,  231,    0,    0,    0,
    0,  221,  243,    0,    0,  243,    0,    0,    0,  231,
    0,  231,  250,  231,  250,    0,    0,    0,  231,  231,
    0,    0,  217,  243,  217,  250,  243,  243,    0,    0,
  233,    0,  233,  221,    0,    0,   64,  250,    0,  217,
  231,   57,    0,  231,    0,  250,  250,  233,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   82,
    0,  231,    0,    0,  231,  231,    0,    0,    0,  250,
    0,  219,  250,  219,  217,    0,  217,    0,   66,    0,
   64,    0,  233,    0,  233,    0,    0,  217,  219,    0,
  250,   84,    0,  250,  250,  233,    0,  159,    0,    0,
    0,   64,  217,    0,   64,   64,    0,    0,    0,  217,
  217,  121,    0,    0,    0,  233,  233,    0,    0,    0,
   23,   24,    0,  219,  231,  219,  231,    0,    0,    0,
    0,  217,    0,  221,  217,  221,  219,    0,    0,  233,
    0,  231,  233,    0,    0,    0,    0,    0,    0,    0,
  221,    0,  217,  100,    0,  217,  217,    0,  219,  219,
  233,    0,    0,  233,  233,  221,  120,  221,    0,    0,
    0,    0,    0,   57,    0,   57,  231,    0,  231,    0,
  219,    0,  221,  219,    0,  221,    0,  221,    0,  231,
   57,   82,    0,   82,    0,    0,  176,    0,  221,    0,
    0,  219,    0,    0,  219,  219,    0,    0,   82,  231,
   66,    0,   66,    0,    0,    0,    0,  221,    0,  221,
  221,  221,    0,   84,    0,   84,    0,   66,    0,  159,
  221,  159,    0,  231,    0,    0,  231,    0,   57,    0,
   84,    0,  221,  121,    0,  121,  159,    0,    0,    0,
    0,    0,    0,    0,  231,    0,   82,  231,  231,    0,
  121,    0,    0,  221,    0,    0,  221,  221,    0,    0,
    0,    0,    0,    0,  221,   66,    0,    0,    0,    0,
    0,    0,   57,    0,    0,    0,    0,    0,   84,    0,
    0,    0,    0,    0,  159,  221,    0,    0,  221,  221,
   82,    0,    0,   57,    0,    0,   57,   57,  121,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   66,
    0,   82,    0,    0,   82,   82,    0,    0,    0,    0,
    0,    0,   84,    0,    0,    0,    0,  277,  159,   25,
   66,    0,    0,   66,   66,    0,    0,    0,    0,    0,
    0,    0,  121,   84,    0,    0,   84,   84,    0,  159,
    0,    0,  159,  159,    0,    0,    0,   92,   93,    0,
    0,    0,    0,  121,   25,    0,  121,  121,    0,    0,
  305,  306,    0,  123,  123,    0,    0,  125,    0,    0,
  127,    0,  240,    0,    0,    0,    0,    0,  161,  123,
  123,    0,    0,    0,  123,  123,  323,  324,    0,    0,
    0,  123,  123,    0,    0,   25,    0,    0,    0,  179,
  180,    0,  181,    0,    0,    0,  185,    0,    0,    0,
    0,  123,  123,  352,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  123,
    0,  361,    0,    0,    0,    0,    0,    0,    0,  123,
  123,  370,    0,    0,    0,  373,    0,    0,  217,   25,
    0,    0,  374,    0,    0,    0,  221,  222,   25,    0,
    0,  224,    0,    0,  226,    0,  114,  384,  229,  230,
  384,    0,    0,  233,  235,  237,  392,    0,    0,  233,
    0,    0,    0,  397,    0,  397,  244,    0,  246,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  237,
    0,    0,    0,    0,    0,    0,    0,    0,  131,  132,
  133,  134,    0,    0,    0,    0,    0,    0,    0,  135,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   25,   25,  274,    0,  151,  136,    0,   79,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  237,    0,  237,
    0,  294,    0,  137,  138,  237,    0,    0,    0,    0,
  139,    0,    0,  140,    0,    0,    0,    0,  300,  141,
    0,  302,    0,    0,  142,    0,  294,    0,    0,    0,
    0,    0,    0,    0,   25,    0,   25,    0,  313,    0,
    0,  314,    0,  317,    0,    0,  113,  320,    0,  322,
   82,    0,  114,  114,  114,  114,  294,  294,  143,  144,
  145,    0,  146,  114,    0,    0,    0,  147,    0,    0,
  148,    0,    0,  149,    0,    0,   25,   25,    0,  114,
    0,  114,    0,  353,  150,    0,    0,    0,   18,   19,
    0,   20,    0,  357,    0,    0,    0,  114,  114,    0,
    0,    0,    0,    0,  114,    0,    0,  114,    0,    0,
    0,    0,    0,  114,  114,    0,  286,    0,  114,  114,
  131,  132,  133,  134,    0,  114,  114,    0,    0,   25,
    0,  135,    0,    0,    0,    0,   25,    0,    0,    0,
    0,    0,    0,    0,  114,  114,  114,  136,    0,   79,
    0,    0,  114,  114,  114,    0,  114,    0,    0,    0,
    0,  114,    0,  114,  114,  137,  138,  114,    0,    0,
    0,    0,  139,    0,    0,  140,    0,    0,  114,    0,
    0,  141,  113,  113,  113,  113,  142,    0,    0,    0,
    0,    0,  331,  113,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  113,
    0,  113,   82,    0,    0,    0,    0,    0,    0,    0,
  143,  144,  145,    0,  146,    0,    0,  113,  113,  147,
    0,    0,  148,    0,  113,  149,    0,  113,    0,    0,
    0,    0,    0,  113,    0,    0,  150,    0,  113,    0,
  131,  132,  133,  134,    0,    0,    0,    0,    0,    0,
    0,  135,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  113,    0,    0,  136,    0,   79,
    0,    0,  113,  113,  113,    0,  113,    0,    0,    0,
    0,  113,    0,    0,  113,  137,  138,  113,    0,    0,
    0,    0,  139,    0,    0,  140,    0,    0,  113,    0,
    0,  141,    0,    0,    0,    0,  142,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  131,  132,  133,  134,
    0,    0,    0,    0,    0,    0,    0,  135,    0,    0,
    0,    0,   82,    0,    0,    0,    0,    0,    0,    0,
  143,  144,  145,  136,  146,   79,    0,    0,    0,  147,
    0,    0,  148,    0,    0,  149,    0,    0,    0,    0,
    0,  137,  138,    0,    0,    0,  150,    0,  139,    0,
    0,  140,    0,    0,    0,    0,    0,  141,  131,  132,
  133,  134,  142,    0,    0,    0,    0,    0,    0,  135,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  136,    0,   79,   82,    0,
    0,    0,    0,    0,    0,    0,  143,  144,  145,    0,
  146,    0,    0,  137,  138,  147,    0,    0,  148,    0,
  139,  149,    0,  140,    0,    0,    0,    0,    0,  141,
    0,    0,  150,    0,  142,    0,  131,  132,  133,  134,
    0,    0,    0,    0,    0,    0,    0,  135,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   82,    0,    0,  136,    0,   79,    0,    0,  143,  144,
  145,    0,  146,    0,    0,    0,    0,  147,    0,    0,
  148,  137,  138,  149,    0,    0,    0,    0,  139,    0,
    0,  140,    0,    0,  150,    0,    0,  141,   18,   19,
    0,   20,  142,    0,    0,   31,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,   33,   34,    0,    0,    0,    0,    0,   82,    0,
    0,   35,   36,    0,    0,    0,  143,  144,  145,    0,
  146,    0,    0,   37,    0,  147,   38,    0,  148,    0,
    0,  149,    0,    0,    0,   39,   40,   41,   42,   43,
    0,    0,  150,    0,   44,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   45,    0,    0,    0,
   46,    0,    0,    0,    0,    0,    0,    0,   47,    0,
    0,    0,    0,    0,    0,   48,   49,   50,   51,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   52,    0,    0,   53,    0,    0,    0,
    0,    0,    0,   54,
};
static const YYINT yycheck[] = {                         43,
    0,   43,  123,   43,   35,   36,   60,   43,   62,  255,
   62,   72,  178,   44,  280,  123,   47,  338,   49,   50,
   51,  275,  266,  123,   53,   56,  342,   60,    0,   62,
   83,  160,  267,  268,  269,   64,  302,   43,  241,  286,
  285,   41,  349,  264,  279,  290,  362,   28,  293,  401,
  123,  272,   60,  331,   62,  184,    0,  273,  410,  266,
  267,  268,  328,  329,  311,  380,  381,  388,  346,  366,
  391,  368,  393,  380,  259,  260,  257,  258,   59,  245,
  301,  297,  263,  264,  389,  390,  252,  392,  341,  386,
  271,   61,  147,  338,  275,  257,  258,  313,  364,    0,
  155,  263,  264,  347,  165,  234,  404,  288,   61,  271,
  408,  327,  164,  275,  412,   43,    4,  289,  384,  172,
  386,  174,  175,  123,  285,  125,  288,  308,  331,  290,
  123,  377,  293,  298,  299,  389,  390,  123,  392,  294,
  295,  170,  323,  378,  283,  388,  308,  178,  391,  125,
  393,   39,  350,  125,  307,  210,  211,  212,  259,  260,
  123,  323,  298,  299,  365,  123,  380,  278,  312,  123,
  351,  351,  351,  311,  388,  312,  228,  391,  296,  393,
  312,  125,  377,  354,  125,  362,  367,   40,  125,  351,
  380,  372,   80,  349,  375,  343,  274,  274,  379,    0,
  334,   44,  335,  349,  339,  367,  337,  125,  389,  390,
  372,  392,  342,  375,  245,  125,   41,  379,  249,  369,
  309,  252,  345,  365,  125,  344,   44,  389,  390,   41,
  392,  240,   71,  287,  362,   30,  362,  277,  365,  363,
  130,  395,  125,  295,  418,  405,  134,  125,  415,  113,
  362,  336,   67,  125,  225,  143,  283,  257,  125,  259,
  260,  261,  262,  383,  125,   57,  266,  372,  389,  390,
  270,  392,  380,  381,  274,  271,  330,  310,  278,  116,
    0,  306,   67,  283,  315,  257,  286,  259,  288,  389,
  390,  334,  392,  290,  294,  295,  296,   -1,  298,  299,
   -1,  332,  274,   -1,  304,  305,   -1,  307,   -1,  309,
   -1,  311,   -1,  257,  314,  259,  389,  390,   -1,  392,
  320,  321,  322,   -1,  125,  325,  326,  215,  216,   -1,
  274,  331,  332,  333,  334,  335,  380,  337,    0,  339,
  382,  377,  342,  343,  344,  345,  346,  347,   -1,  349,
  322,  351,  352,  353,  354,   -1,  257,   -1,  259,  359,
  360,  361,   -1,  363,   -1,  309,  366,  311,  368,  369,
  370,  371,   -1,  274,  374,   -1,  382,  377,  322,   -1,
  380,  381,   -1,  389,  390,  385,  392,  387,  289,  389,
  390,  391,  392,  337,  366,  339,  389,  390,   -1,  392,
  344,  345,   -1,  389,  390,  125,  392,   -1,  309,   -1,
  311,  312,   -1,  389,  390,  387,  392,   -1,  390,  391,
   -1,  322,  366,  311,  312,  369,  389,  390,   -1,  392,
   -1,  389,  390,  334,  392,  389,  390,   -1,  392,   -1,
   -1,  342,  343,  387,   -1,   -1,  390,  391,  389,  390,
   -1,  392,  389,  390,   -1,  392,  257,    0,  259,  260,
  261,  262,   -1,  125,   -1,  366,   -1,    0,  369,  270,
   -1,  389,  390,  274,  392,   -1,  364,  278,   -1,  389,
  390,  123,  392,  371,   -1,  286,  387,  288,  389,  390,
  391,  392,  123,  294,  295,  296,   -1,  298,  299,   -1,
    0,   -1,   -1,  304,  305,   -1,  389,  390,  309,  392,
  311,  389,  390,  314,  392,   -1,    0,  389,  390,  320,
  392,  322,  389,  390,  325,  392,   -1,   -1,  389,  390,
  331,  392,   -1,  334,  335,   -1,  337,  257,  339,  259,
   -1,  342,  343,  344,  345,  346,   -1,   -1,  349,   -1,
  351,   -1,   -1,   -1,  274,   -1,   -1,   -1,  359,  360,
  361,   -1,  363,   -1,   -1,  366,   -1,  368,  369,   -1,
  371,   -1,   -1,  374,   -1,    0,  377,   -1,   -1,  380,
   -1,   -1,  125,   -1,  385,   -1,  387,   -1,   -1,  390,
  391,  311,  125,   -1,   -1,  257,   -1,  259,  260,  261,
  262,   -1,  322,   -1,   -1,   -1,   -1,   -1,  270,   -1,
   -1,   -1,  274,   -1,  334,   -1,  278,  259,  260,   -1,
   -1,   -1,   -1,   -1,  286,  125,  288,   -1,  259,  260,
   -1,   -1,  294,  295,   -1,   -1,  298,  299,   -1,   -1,
   -1,  125,  304,  305,   -1,   -1,  366,  309,   -1,  311,
   -1,   -1,  314,   -1,   -1,   -1,    0,   -1,  320,   -1,
  322,   -1,   -1,  325,   -1,   -1,   -1,  387,   -1,  331,
  390,  391,  334,  335,   -1,  337,   -1,  339,   -1,   -1,
  342,  343,  344,  345,  346,   -1,   -1,   -1,   -1,  351,
   -1,   -1,   -1,   -1,    0,   -1,   -1,  359,  360,  361,
  125,  363,   -1,   -1,  366,   -1,  368,  369,   -1,  371,
   -1,   -1,  374,   -1,  257,   -1,  259,  260,  261,  262,
   -1,   -1,   -1,  385,  257,  387,  259,  270,  390,  391,
   -1,  274,   -1,   -1,  123,  278,   -1,    0,  380,  381,
   -1,  274,   -1,  286,   -1,  288,   -1,   -1,   -1,  380,
  381,  294,  295,    0,   -1,   -1,   -1,  257,   -1,  259,
   -1,  304,  305,   -1,   -1,   -1,  309,   -1,  311,   -1,
   -1,  314,   -1,  257,  274,  259,   -1,  320,  311,  322,
   -1,  125,  325,  388,  389,  390,  391,  392,  393,  322,
  274,   -1,  335,   -1,  337,   -1,  339,   -1,  331,   -1,
  343,  344,  345,   -1,   -1,   -1,   -1,   -1,  351,  309,
   -1,  311,    0,  346,   -1,   -1,  359,  360,  361,  125,
  363,   -1,  322,  366,   -1,  368,  369,  311,  371,   -1,
   -1,  374,  257,  366,  259,  260,  261,  262,  322,  125,
   -1,   -1,  385,   -1,  387,  270,   -1,  390,  391,  274,
   -1,   -1,   -1,  278,  387,   -1,   -1,  390,  391,   -1,
  344,  286,  125,  288,   -1,   -1,  366,   -1,   -1,  369,
  259,  260,    0,   -1,   -1,   -1,   -1,  266,  125,  304,
  305,   -1,  366,   -1,  309,   -1,  311,  387,   -1,  314,
  390,  391,   -1,   -1,   -1,  320,   -1,  322,   -1,   -1,
  325,   -1,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
  335,   -1,  337,  257,  339,  259,   -1,   -1,  343,  344,
  345,   -1,   -1,   -1,   -1,   -1,  351,   -1,   -1,   -1,
  274,    0,   -1,   -1,  359,  360,  361,  125,  363,   -1,
   -1,  366,   -1,  368,  369,   -1,  371,   -1,   -1,  374,
   -1,  257,   -1,  259,  260,  261,  262,   -1,  347,   -1,
  385,   -1,  387,   -1,  270,  390,  391,  311,  274,   -1,
   -1,  257,  278,  259,    0,   -1,   -1,   -1,  322,   -1,
  286,   -1,  288,   -1,   -1,   -1,   -1,   -1,  274,   -1,
   -1,  380,  381,    0,  257,   -1,  259,  125,  304,  305,
  344,  345,   -1,  309,   -1,  311,   -1,   -1,  314,   -1,
  257,  274,  259,   -1,  320,   -1,  322,   -1,   -1,  325,
   -1,   -1,  366,  123,   -1,   -1,   -1,  274,   -1,  335,
   -1,  337,   -1,  339,   -1,   -1,  322,  343,  344,  345,
   -1,   -1,   -1,  387,   -1,  351,  390,  391,  311,    0,
   -1,   -1,   -1,  359,  360,  361,  125,  363,   -1,  322,
  366,   -1,  368,  369,  311,  371,   -1,   -1,  374,  257,
   -1,  259,  260,  261,  262,  322,   -1,   -1,   -1,  385,
  366,  387,  270,  380,  390,  391,  274,   -1,   -1,  123,
  278,  388,  389,  390,  391,  392,  393,   -1,  286,  125,
  288,  387,   -1,  366,  390,  391,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  304,  305,  125,  366,
   -1,  309,   -1,  311,  387,   -1,  314,  390,  391,  257,
    0,  259,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,
  387,   -1,   -1,  390,  391,   -1,  274,  335,   -1,  337,
   -1,  339,   -1,   -1,   -1,   -1,  344,  345,   -1,  259,
  260,   -1,   -1,  351,   -1,   -1,  266,   -1,    0,   -1,
   -1,  359,  360,  361,  125,  363,   -1,   -1,  366,   -1,
  368,  369,   -1,  371,   -1,   -1,  374,   -1,  257,   -1,
  259,  260,  261,  262,  322,   -1,   -1,  385,   -1,  387,
   -1,  270,  390,  391,   -1,  274,   -1,  123,   -1,  278,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  286,   -1,  288,
   -1,   -1,   -1,   -1,   -1,  259,  260,    0,   -1,   -1,
   -1,  257,  266,  259,   -1,  304,  305,   -1,  366,   -1,
  309,   -1,  311,   -1,   -1,  314,   -1,  347,  274,   -1,
  257,  320,  259,  322,   -1,  125,  325,   -1,   -1,  387,
   -1,   -1,  390,  391,   -1,   -1,   -1,  274,  337,   -1,
  339,   -1,   -1,   -1,   -1,  344,  345,   -1,   -1,   -1,
  380,  381,  351,  309,   -1,  311,    0,  294,  295,   -1,
  359,  360,  361,  125,  363,   -1,  322,  366,   -1,  368,
  369,   -1,  371,   -1,  311,  374,  257,   -1,  259,  260,
  261,  262,   -1,  347,   -1,  322,  385,   -1,  387,  270,
   -1,  390,  391,  274,  331,   -1,  123,  278,    0,   -1,
   -1,   -1,   -1,   -1,   -1,  286,   -1,  288,   -1,  346,
  366,   -1,   -1,  259,  260,   -1,  380,  381,   -1,   -1,
  266,   -1,  125,  304,  305,  123,   -1,   -1,  309,  366,
  311,  387,   -1,  314,  390,  391,   -1,   -1,   -1,  320,
   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
  387,    0,   -1,  390,  391,   -1,  337,  257,   -1,  259,
   -1,   -1,   -1,  344,  345,   -1,   -1,   -1,   -1,   -1,
  351,   -1,   -1,   -1,  274,   -1,   -1,   -1,  359,  360,
  361,  125,  363,   -1,   -1,  366,   -1,  368,  369,   -1,
  371,   -1,   -1,  374,   -1,  257,   -1,  259,  260,  261,
  262,  347,   -1,   -1,  385,   -1,  387,   -1,  270,  390,
  391,  311,  274,   -1,   -1,   -1,  278,   -1,   -1,   -1,
   -1,  123,  322,  125,  286,   -1,  288,   -1,   -1,   -1,
   -1,   -1,  259,  260,  380,  381,   -1,   -1,   -1,  266,
   -1,   -1,  304,  305,   -1,   -1,    0,  309,   -1,  311,
   -1,   -1,  314,   -1,  257,   -1,  259,   -1,  320,   -1,
  322,  259,  260,  325,   -1,   -1,  366,   -1,  266,   -1,
   -1,  274,   -1,   -1,   -1,   -1,  125,   -1,   -1,   -1,
   -1,   -1,  344,  345,   -1,   -1,   -1,  387,   -1,  351,
  390,  391,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,
   -1,  363,   -1,   -1,  366,   -1,  368,  369,  311,  371,
   -1,   -1,  374,  257,   -1,  259,  260,  261,  262,  322,
  347,   -1,   -1,  385,   -1,  387,  270,   -1,  390,  391,
  274,   -1,   -1,   -1,  278,   -1,   -1,   -1,   -1,   -1,
   -1,    0,  286,   -1,  288,   -1,   -1,   -1,   -1,  347,
   -1,   -1,   -1,  380,  381,  257,   -1,  259,  260,   -1,
  304,  305,   -1,  366,  266,  309,   -1,  311,   -1,   -1,
  314,  125,  274,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,  380,  381,  387,   -1,   -1,  390,  391,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  344,  345,   -1,   -1,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
  322,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,  304,  305,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,  347,  390,  391,  320,  321,
   -1,   -1,   -1,  325,  326,  304,  305,   -1,   -1,   -1,
  332,  333,  311,   -1,  366,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,  380,  381,
  352,  353,   -1,   -1,   -1,  387,   -1,   -1,  390,  391,
   -1,   -1,   -1,   -1,   -1,  344,  345,   -1,  370,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,  304,  305,   -1,
   -1,    0,  286,   -1,  288,   -1,  385,   -1,  387,   -1,
   -1,  390,  391,  320,  321,   -1,   -1,   -1,  325,  326,
  304,  305,   -1,   -1,   -1,  332,  333,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,  352,  353,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,   -1,  377,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,   -1,  377,   -1,
   -1,    0,  286,   -1,  288,   -1,  385,   -1,  387,   -1,
   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,   -1,   -1,   -1,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  344,   -1,   -1,   -1,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,   -1,   -1,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,   -1,   -1,   -1,
   -1,    0,  286,   -1,  288,   -1,  385,   -1,  387,   -1,
   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,   -1,   -1,   -1,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,   -1,   -1,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,   -1,   -1,   -1,
   -1,    0,  286,   -1,  288,   -1,  385,   -1,  387,   -1,
   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,   -1,   -1,   -1,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,   -1,   -1,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,   -1,   -1,   -1,
   -1,    0,  286,   -1,  288,   -1,  385,   -1,  387,   -1,
   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,   -1,   -1,   -1,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,   -1,   -1,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,   -1,   -1,   -1,
   -1,    0,  286,   -1,  288,   -1,  385,   -1,  387,   -1,
   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,   -1,   -1,   -1,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,   -1,   -1,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,   -1,   -1,   -1,
   -1,    0,  286,   -1,  288,   -1,  385,   -1,  387,   -1,
   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,   -1,   -1,   -1,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,   -1,   -1,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,   -1,   -1,   -1,
   -1,    0,  286,   -1,  288,   -1,  385,   -1,  387,   -1,
   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,    0,   -1,   -1,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,   -1,   -1,   -1,   -1,   -1,    0,  286,   -1,  288,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,  125,   -1,   -1,   -1,
   -1,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  123,   -1,  125,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  351,  257,   -1,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,   -1,  371,   -1,  278,  374,   -1,   -1,   -1,   -1,
   -1,   -1,  286,   -1,  288,    0,  385,   -1,  387,   -1,
   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,    0,   -1,   -1,  311,   -1,   -1,
  314,  125,   -1,   -1,   -1,   -1,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,    0,   -1,   -1,  351,  257,   -1,
  259,  260,  261,  262,   -1,  359,  360,  361,   -1,  363,
   -1,  270,  366,   -1,  368,  274,   -1,  371,   -1,  278,
  374,  257,   -1,  259,  260,   -1,   -1,  286,   -1,  288,
  266,  385,   -1,  387,   -1,   -1,  390,  391,  274,   -1,
   -1,   -1,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,    0,   -1,   -1,   -1,
  125,  320,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  125,
   -1,   -1,   -1,   -1,   -1,   -1,  322,   -1,   -1,   -1,
   -1,   -1,  351,  257,    0,  259,  260,  261,  262,   -1,
  359,  360,  361,   -1,  363,   -1,  270,  366,   -1,  368,
  274,  347,  371,   -1,  278,  374,   -1,   -1,   -1,  125,
   -1,   -1,  286,    0,  288,   -1,  385,   -1,  387,   -1,
  366,  390,  391,   -1,    0,   -1,   -1,   -1,   -1,   -1,
  304,  305,   -1,   -1,  380,  381,   -1,  311,   -1,   -1,
  314,  387,   -1,   -1,  390,  391,  320,   -1,  322,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  125,   -1,   -1,   -1,    0,   -1,  351,   -1,   -1,
   -1,   -1,  257,    0,  259,  359,  360,  361,   -1,  363,
   -1,   -1,  366,   -1,  368,   -1,   -1,  371,   -1,  274,
  374,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  125,
   -1,  385,   -1,  387,   -1,   -1,  390,  391,  274,  294,
  295,   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  309,   -1,  311,   -1,  125,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,  322,   -1,  125,
   -1,   -1,   -1,  309,   -1,  311,  331,   -1,  274,   -1,
  335,   -1,  337,   -1,  339,   -1,  322,   -1,  343,  344,
  345,  346,   -1,   -1,   -1,  331,   -1,    0,   -1,  335,
   -1,  337,   -1,  339,   -1,   -1,    0,  343,  344,  345,
  346,  366,   -1,  309,  369,  311,   -1,   -1,   -1,   -1,
  125,   -1,   -1,  257,   -1,  259,  322,   -1,  125,   -1,
  366,   -1,  387,  369,   -1,  390,  391,   -1,    0,  335,
  274,  337,   -1,  339,   -1,   -1,    0,  343,  344,  345,
   -1,  387,   -1,   -1,  390,  391,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,    0,   -1,   -1,   -1,   -1,  125,
  366,   -1,   -1,  369,   -1,  309,   -1,  311,  274,   -1,
   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,  322,   -1,
  257,  387,  259,   -1,  390,  391,    0,  331,   -1,   -1,
  334,  257,    0,  259,   -1,   -1,   -1,  274,  342,  343,
   -1,   -1,  346,  309,   -1,  311,    0,   -1,  274,   -1,
   -1,   -1,  125,   -1,   -1,   -1,  322,   -1,   -1,   -1,
   -1,  125,  366,   -1,   -1,  369,   -1,   -1,   -1,  335,
   -1,  337,  309,  339,  311,   -1,   -1,   -1,  344,  345,
   -1,   -1,  257,  387,  259,  322,  390,  391,   -1,   -1,
  257,   -1,  259,  125,   -1,   -1,  322,  334,   -1,  274,
  366,  125,   -1,  369,   -1,  342,  343,  274,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  125,
   -1,  387,   -1,   -1,  390,  391,   -1,   -1,   -1,  366,
   -1,  257,  369,  259,  309,   -1,  311,   -1,  125,   -1,
  366,   -1,  309,   -1,  311,   -1,   -1,  322,  274,   -1,
  387,  125,   -1,  390,  391,  322,   -1,  125,   -1,   -1,
   -1,  387,  337,   -1,  390,  391,   -1,   -1,   -1,  344,
  345,  125,   -1,   -1,   -1,  342,  343,   -1,   -1,   -1,
    2,    3,   -1,  309,  257,  311,  259,   -1,   -1,   -1,
   -1,  366,   -1,  257,  369,  259,  322,   -1,   -1,  366,
   -1,  274,  369,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  274,   -1,  387,   35,   -1,  390,  391,   -1,  344,  345,
  387,   -1,   -1,  390,  391,  257,   48,  259,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,  309,   -1,  311,   -1,
  366,   -1,  274,  369,   -1,  309,   -1,  311,   -1,  322,
  274,  257,   -1,  259,   -1,   -1,   78,   -1,  322,   -1,
   -1,  387,   -1,   -1,  390,  391,   -1,   -1,  274,  342,
  257,   -1,  259,   -1,   -1,   -1,   -1,  309,   -1,  311,
  344,  345,   -1,  257,   -1,  259,   -1,  274,   -1,  257,
  322,  259,   -1,  366,   -1,   -1,  369,   -1,  322,   -1,
  274,   -1,  366,  257,   -1,  259,  274,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  387,   -1,  322,  390,  391,   -1,
  274,   -1,   -1,  387,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,   -1,  366,  322,   -1,   -1,   -1,   -1,
   -1,   -1,  366,   -1,   -1,   -1,   -1,   -1,  322,   -1,
   -1,   -1,   -1,   -1,  322,  387,   -1,   -1,  390,  391,
  366,   -1,   -1,  387,   -1,   -1,  390,  391,  322,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  366,
   -1,  387,   -1,   -1,  390,  391,   -1,   -1,   -1,   -1,
   -1,   -1,  366,   -1,   -1,   -1,   -1,  219,  366,    4,
  387,   -1,   -1,  390,  391,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  366,  387,   -1,   -1,  390,  391,   -1,  387,
   -1,   -1,  390,  391,   -1,   -1,   -1,   32,   33,   -1,
   -1,   -1,   -1,  387,   39,   -1,  390,  391,   -1,   -1,
  262,  263,   -1,  304,  305,   -1,   -1,   52,   -1,   -1,
   55,   -1,  123,   -1,   -1,   -1,   -1,   -1,   63,  320,
  321,   -1,   -1,   -1,  325,  326,  288,  289,   -1,   -1,
   -1,  332,  333,   -1,   -1,   80,   -1,   -1,   -1,   84,
   85,   -1,   87,   -1,   -1,   -1,   91,   -1,   -1,   -1,
   -1,  352,  353,  315,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  380,
  381,  343,   -1,   -1,   -1,  347,   -1,   -1,  133,  134,
   -1,   -1,  354,   -1,   -1,   -1,  141,  142,  143,   -1,
   -1,  146,   -1,   -1,  149,   -1,  123,  369,  153,  154,
  372,   -1,   -1,  158,  159,  160,  378,   -1,   -1,  164,
   -1,   -1,   -1,  385,   -1,  387,  171,   -1,  173,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  184,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  259,  260,
  261,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  270,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  215,  216,  217,   -1,  123,  286,   -1,  288,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  232,   -1,  234,
   -1,  236,   -1,  304,  305,  240,   -1,   -1,   -1,   -1,
  311,   -1,   -1,  314,   -1,   -1,   -1,   -1,  253,  320,
   -1,  256,   -1,   -1,  325,   -1,  261,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  269,   -1,  271,   -1,  273,   -1,
   -1,  276,   -1,  278,   -1,   -1,  123,  282,   -1,  284,
  351,   -1,  259,  260,  261,  262,  291,  292,  359,  360,
  361,   -1,  363,  270,   -1,   -1,   -1,  368,   -1,   -1,
  371,   -1,   -1,  374,   -1,   -1,  311,  312,   -1,  286,
   -1,  288,   -1,  318,  385,   -1,   -1,   -1,  389,  390,
   -1,  392,   -1,  328,   -1,   -1,   -1,  304,  305,   -1,
   -1,   -1,   -1,   -1,  311,   -1,   -1,  314,   -1,   -1,
   -1,   -1,   -1,  320,  321,   -1,  125,   -1,  325,  326,
  259,  260,  261,  262,   -1,  332,  333,   -1,   -1,  364,
   -1,  270,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  351,  352,  353,  286,   -1,  288,
   -1,   -1,  359,  360,  361,   -1,  363,   -1,   -1,   -1,
   -1,  368,   -1,  370,  371,  304,  305,  374,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,   -1,   -1,  385,   -1,
   -1,  320,  259,  260,  261,  262,  325,   -1,   -1,   -1,
   -1,   -1,  125,  270,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  286,
   -1,  288,  351,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,   -1,  363,   -1,   -1,  304,  305,  368,
   -1,   -1,  371,   -1,  311,  374,   -1,  314,   -1,   -1,
   -1,   -1,   -1,  320,   -1,   -1,  385,   -1,  325,   -1,
  259,  260,  261,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  351,   -1,   -1,  286,   -1,  288,
   -1,   -1,  359,  360,  361,   -1,  363,   -1,   -1,   -1,
   -1,  368,   -1,   -1,  371,  304,  305,  374,   -1,   -1,
   -1,   -1,  311,   -1,   -1,  314,   -1,   -1,  385,   -1,
   -1,  320,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  259,  260,  261,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  270,   -1,   -1,
   -1,   -1,  351,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  286,  363,  288,   -1,   -1,   -1,  368,
   -1,   -1,  371,   -1,   -1,  374,   -1,   -1,   -1,   -1,
   -1,  304,  305,   -1,   -1,   -1,  385,   -1,  311,   -1,
   -1,  314,   -1,   -1,   -1,   -1,   -1,  320,  259,  260,
  261,  262,  325,   -1,   -1,   -1,   -1,   -1,   -1,  270,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  286,   -1,  288,  351,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,   -1,
  363,   -1,   -1,  304,  305,  368,   -1,   -1,  371,   -1,
  311,  374,   -1,  314,   -1,   -1,   -1,   -1,   -1,  320,
   -1,   -1,  385,   -1,  325,   -1,  259,  260,  261,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  270,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  351,   -1,   -1,  286,   -1,  288,   -1,   -1,  359,  360,
  361,   -1,  363,   -1,   -1,   -1,   -1,  368,   -1,   -1,
  371,  304,  305,  374,   -1,   -1,   -1,   -1,  311,   -1,
   -1,  314,   -1,   -1,  385,   -1,   -1,  320,  389,  390,
   -1,  392,  325,   -1,   -1,  265,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  276,   -1,   -1,   -1,
   -1,  281,  282,   -1,   -1,   -1,   -1,   -1,  351,   -1,
   -1,  291,  292,   -1,   -1,   -1,  359,  360,  361,   -1,
  363,   -1,   -1,  303,   -1,  368,  306,   -1,  371,   -1,
   -1,  374,   -1,   -1,   -1,  315,  316,  317,  318,  319,
   -1,   -1,  385,   -1,  324,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,   -1,   -1,   -1,   -1,  355,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  373,   -1,   -1,  376,   -1,   -1,   -1,
   -1,   -1,   -1,  383,
};
#if YYBTYACC
static const YYINT yyctable[] = {                        -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,
};
#endif
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 393
#define YYUNDFTOKEN 485
#define YYTRANSLATE(a) ((a) > YYMAXTOKEN ? YYUNDFTOKEN : (a))
#if YYDEBUG
static const char *const yyname[] = {

"$end",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,"'('","')'",0,"'+'","','",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'<'","'='","'>'",
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
"error","TOKACCOUNT","TOKACCOUNTS","TOKACTION","TOKACTIONS","TOKADDHEADER",
"TOKADDTOCACHE","TOKAGE","TOKALL","TOKALLOWMANY","TOKAND","TOKANYNAME",
"TOKANYSIZE","TOKANYTYPE","TOKAPPEND","TOKATTACHMENT","TOKBODY","TOKBYTES",
"TOKCACHE","TOKCASE","TOKCMDUSER","TOKCOMPRESS","TOKCONTINUE","TOKCOUNT",
"TOKDAYS","TOKDEFUSER","TOKDELTOOBIG","TOKDISABLED","TOKDOMAIN","TOKDOTLOCK",
"TOKDROP","TOKEQ","TOKEXEC","TOKEXPIRE","TOKFCNTL","TOKFILEGROUP",
"TOKFILEUMASK","TOKFLOCK","TOKFOLDER","TOKFOLDERS","TOKFROM","TOKGIGABYTES",
"TOKGROUP","TOKGROUPS","TOKHEADER","TOKHEADERS","TOKHOURS","TOKIGNOREERRORS",
"TOKIMAP","TOKIMAPS","TOKIMPLACT","TOKIN","TOKINCACHE","TOKINSECURE",
"TOKINVALID","TOKKEEP","TOKKEY","TOKKILOBYTES","TOKLMTP","TOKLOCKFILE",
"TOKLOCKTIMEOUT","TOKLOCKTYPES","TOKLOCKWAIT","TOKLOOKUPORDER","TOKMAILDIR",
"TOKMAILDIRS","TOKMATCH","TOKMATCHED","TOKMAXSIZE","TOKMBOX","TOKMBOXES",
"TOKMEGABYTES","TOKMINUTES","TOKMONTHS","TOKNE","TOKNEWONLY","TOKNNTP",
"TOKNNTPS","TOKNOAPOP","TOKNOCRAMMD5","TOKNOCREATE","TOKNOLOGIN","TOKNONE",
"TOKNOPLAIN","TOKNORECEIVED","TOKNOT","TOKNOUIDL","TOKNOVERIFY","TOKXOAUTH2",
"TOKOAUTHBEARER","TOKOLDONLY","TOKOR","TOKPARALLELACCOUNTS","TOKPASS",
"TOKPASSWD","TOKPIPE","TOKPOP3","TOKPOP3S","TOKPORT","TOKPROXY","TOKPURGEAFTER",
"TOKQUEUEHIGH","TOKQUEUELOW","TOKREMOVEFROMCACHE","TOKREMOVEHEADER",
"TOKREMOVEHEADERS","TOKRETURNS","TOKREWRITE","TOKSECONDS","TOKSERVER","TOKSET",
"TOKSIZE","TOKSMTP","TOKSTARTTLS","TOKSTDIN","TOKSTDOUT","TOKSTRING",
"TOKSTRIPCHARACTERS","TOKTAG","TOKTAGGED","TOKTIMEOUT","TOKTO","TOKTOTALSIZE",
"TOKUNMATCHED","TOKUSER","TOKUSERS","TOKVALUE","TOKVERIFYCERTS","TOKWEEKS",
"TOKWRITE","TOKYEARS","NONE","NUMBER","STRING","STRMACRO","NUMMACRO",
"STRCOMMAND","NUMCOMMAND","$accept","cmds","actitem","actlist","area","cmp",
"ltgt","eqne","expr","exprlist","expritem","exprop","fetchtype","cont","not",
"disabled","keep","execpipe","writeappend","compress","verify","apop","poptype",
"imaptype","nntptype","nocrammd5","noplain","nologin","uidl","starttls",
"insecure","oauthbearer","xoauth2","localgid","lock","locklist","size","time",
"numv","retrc","expire","only","imaponly","poponly","replstrslist","actions",
"rmheaders","accounts","users","casere","retre","perform","server","port","to",
"from","xstrv","strv","replstrv","replpathv","val","optval","folder1","user",
"stringslist","pathslist","maildirs","mboxes","groups","folders","folderlist",
"userpass","userpassreqd","userpassnetrc","ufn","ufnlist","account","defaction",
"defmacro","rule","set","close","cache","actionp","userp","accountp","groupp",
"folderp","maildirp","mboxp","rmheaderp","illegal-symbol",
};
static const char *const yyrule[] = {
"$accept : cmds",
"cmds :",
"cmds : cmds account",
"cmds : cmds defaction",
"cmds : cmds defmacro",
"cmds : cmds rule",
"cmds : cmds set",
"cmds : cmds close",
"cmds : cmds cache",
"cmds : cmds NONE",
"actionp : TOKACTION",
"actionp : TOKACTIONS",
"userp : TOKUSER",
"userp : TOKUSERS",
"accountp : TOKACCOUNT",
"accountp : TOKACCOUNTS",
"groupp : TOKGROUP",
"groupp : TOKGROUPS",
"folderp : TOKFOLDER",
"folderp : TOKFOLDERS",
"maildirp : TOKMAILDIR",
"maildirp : TOKMAILDIRS",
"mboxp : TOKMBOX",
"mboxp : TOKMBOXES",
"rmheaderp : TOKREMOVEHEADER",
"rmheaderp : TOKREMOVEHEADERS",
"val : TOKVALUE strv",
"val : strv",
"optval : TOKVALUE strv",
"optval :",
"xstrv : STRCOMMAND",
"xstrv : STRING",
"xstrv : STRMACRO",
"strv : xstrv",
"strv : strv '+' xstrv",
"numv : NUMCOMMAND",
"numv : NUMBER",
"numv : NUMMACRO",
"replstrv : strv",
"replpathv : strv",
"size : numv",
"size : numv TOKBYTES",
"size : numv TOKKILOBYTES",
"size : numv TOKMEGABYTES",
"size : numv TOKGIGABYTES",
"time : numv",
"time : numv TOKHOURS",
"time : numv TOKMINUTES",
"time : numv TOKSECONDS",
"time : numv TOKDAYS",
"time : numv TOKWEEKS",
"time : numv TOKMONTHS",
"time : numv TOKYEARS",
"expire : TOKEXPIRE time",
"expire :",
"cache : TOKCACHE replpathv expire",
"set : TOKSET TOKMAXSIZE size",
"set : TOKSET TOKLOCKTYPES locklist",
"set : TOKSET TOKLOCKFILE replpathv",
"set : TOKSET TOKLOCKWAIT",
"set : TOKSET TOKLOCKTIMEOUT time",
"set : TOKSET TOKDELTOOBIG",
"set : TOKSET TOKIGNOREERRORS",
"set : TOKSET TOKALLOWMANY",
"set : TOKSET TOKDEFUSER strv",
"set : TOKSET TOKCMDUSER strv",
"set : TOKSET TOKSTRIPCHARACTERS strv",
"set : TOKSET TOKTIMEOUT time",
"set : TOKSET TOKQUEUEHIGH numv",
"set : TOKSET TOKQUEUELOW numv",
"set : TOKSET TOKPARALLELACCOUNTS numv",
"set : TOKSET TOKPROXY replstrv",
"set : TOKSET TOKVERIFYCERTS",
"set : TOKSET TOKIMPLACT TOKKEEP",
"set : TOKSET TOKIMPLACT TOKDROP",
"set : TOKSET TOKPURGEAFTER numv",
"set : TOKSET TOKPURGEAFTER TOKNONE",
"set : TOKSET TOKNORECEIVED",
"set : TOKSET TOKNOCREATE",
"set : TOKSET TOKFILEGROUP TOKUSER",
"set : TOKSET TOKFILEGROUP localgid",
"set : TOKSET TOKFILEUMASK TOKUSER",
"set : TOKSET TOKLOOKUPORDER ufnlist",
"set : TOKSET TOKFILEUMASK numv",
"defmacro : STRMACRO '=' strv",
"defmacro : NUMMACRO '=' numv",
"replstrslist : replstrslist strv",
"replstrslist : strv",
"stringslist : stringslist replstrv",
"stringslist : replstrv",
"pathslist : pathslist replpathv",
"pathslist : replpathv",
"ufn : TOKPASSWD",
"ufnlist : ufnlist ufn",
"ufnlist : ufn",
"rmheaders : rmheaderp strv",
"rmheaders : rmheaderp '{' replstrslist '}'",
"maildirs : maildirp replpathv",
"maildirs : maildirp '{' pathslist '}'",
"mboxes : mboxp replpathv",
"mboxes : mboxp '{' pathslist '}'",
"folders : folderp replstrv",
"folders : folderp '{' stringslist '}'",
"lock : TOKFCNTL",
"lock : TOKFLOCK",
"lock : TOKDOTLOCK",
"locklist : locklist lock",
"locklist : lock",
"locklist : TOKNONE",
"localgid : replstrv",
"localgid : numv",
"user :",
"user : TOKUSER strv",
"users :",
"users : userp strv",
"users : userp '{' replstrslist '}'",
"casere : TOKCASE replstrv",
"casere : replstrv",
"not : TOKNOT",
"not :",
"keep : TOKKEEP",
"keep :",
"disabled : TOKDISABLED",
"disabled :",
"port : TOKPORT replstrv",
"port : TOKPORT numv",
"server : TOKSERVER replstrv port",
"server : TOKSERVER replstrv",
"to :",
"to : TOKTO strv",
"from :",
"from : TOKFROM strv",
"compress : TOKCOMPRESS",
"compress :",
"actitem : execpipe strv",
"actitem : TOKREWRITE strv",
"actitem : writeappend strv",
"actitem : TOKMAILDIR strv",
"actitem : rmheaders",
"actitem : TOKADDHEADER strv val",
"actitem : TOKMBOX strv compress",
"actitem : imaptype server userpassnetrc folder1 verify nocrammd5 noplain nologin starttls insecure oauthbearer xoauth2",
"actitem : TOKSMTP server from to",
"actitem : TOKLMTP server from to",
"actitem : TOKSTDOUT",
"actitem : TOKTAG strv optval",
"actitem : TOKADDTOCACHE replpathv TOKKEY strv",
"actitem : TOKREMOVEFROMCACHE replpathv TOKKEY strv",
"actitem : actions",
"actitem : TOKDROP",
"actitem : TOKKEEP",
"actlist : actlist actitem",
"actlist : actitem",
"defaction : TOKACTION replstrv users actitem",
"defaction : TOKACTION replstrv users '{' actlist '}'",
"accounts : accountp strv",
"accounts : accountp '{' replstrslist '}'",
"actions : actionp strv",
"actions : actionp '{' replstrslist '}'",
"cont :",
"cont : TOKCONTINUE",
"area :",
"area : TOKIN TOKALL",
"area : TOKIN TOKHEADERS",
"area : TOKIN TOKBODY",
"retrc : numv",
"retrc :",
"retre : casere",
"retre :",
"ltgt : '<'",
"ltgt : '>'",
"eqne : TOKEQ",
"eqne : TOKNE",
"cmp : ltgt",
"cmp : eqne",
"execpipe : TOKEXEC",
"execpipe : TOKPIPE",
"writeappend : TOKWRITE",
"writeappend : TOKAPPEND",
"exprop : TOKAND",
"exprop : TOKOR",
"expritem : not TOKALL",
"expritem : not casere area",
"expritem : not accounts",
"expritem : not execpipe strv user TOKRETURNS '(' retrc ',' retre ')'",
"expritem : not TOKTAGGED strv",
"expritem : not TOKSIZE ltgt size",
"expritem : not TOKSTRING strv TOKTO casere",
"expritem : not TOKINCACHE replpathv TOKKEY strv",
"expritem : not TOKMATCHED",
"expritem : not TOKUNMATCHED",
"expritem : not TOKAGE ltgt time",
"expritem : not TOKAGE TOKINVALID",
"expritem : not TOKATTACHMENT TOKCOUNT cmp numv",
"expritem : not TOKATTACHMENT TOKTOTALSIZE ltgt size",
"expritem : not TOKATTACHMENT TOKANYSIZE ltgt size",
"expritem : not TOKATTACHMENT TOKANYTYPE strv",
"expritem : not TOKATTACHMENT TOKANYNAME strv",
"exprlist : exprlist exprop expritem",
"exprlist : exprop expritem",
"expr : expritem",
"expr : expritem exprlist",
"perform : users actionp actitem cont",
"perform : users actionp '{' actlist '}' cont",
"perform : users actions cont",
"perform : '{'",
"close : '}'",
"rule : TOKMATCH expr perform",
"folderlist :",
"folderlist : folders",
"folder1 :",
"folder1 : folderp strv",
"groups : groupp replstrv",
"groups : groupp '{' stringslist '}'",
"nocrammd5 : TOKNOCRAMMD5",
"nocrammd5 :",
"noplain : TOKNOPLAIN",
"noplain :",
"nologin : TOKNOLOGIN",
"nologin :",
"starttls : TOKSTARTTLS",
"starttls :",
"uidl : TOKNOUIDL",
"uidl :",
"insecure : TOKINSECURE",
"insecure :",
"oauthbearer : TOKOAUTHBEARER",
"oauthbearer :",
"xoauth2 : TOKXOAUTH2",
"xoauth2 :",
"verify : TOKNOVERIFY",
"verify :",
"apop : TOKNOAPOP",
"apop :",
"only : TOKNEWONLY",
"only : TOKOLDONLY",
"poptype : TOKPOP3",
"poptype : TOKPOP3S",
"imaptype : TOKIMAP",
"imaptype : TOKIMAPS",
"nntptype : TOKNNTP",
"nntptype : TOKNNTPS",
"userpassnetrc : TOKUSER replstrv TOKPASS replstrv",
"userpassnetrc :",
"userpassnetrc : TOKUSER replstrv",
"userpassnetrc : TOKPASS replstrv",
"userpassreqd : TOKUSER replstrv TOKPASS replstrv",
"userpass : userpassreqd",
"userpass :",
"poponly : only TOKCACHE replpathv",
"poponly :",
"imaponly : only",
"imaponly :",
"fetchtype : poptype server userpassnetrc poponly apop verify uidl starttls insecure",
"fetchtype : TOKPOP3 TOKPIPE replstrv userpassreqd poponly apop",
"fetchtype : imaptype server userpassnetrc folderlist imaponly verify nocrammd5 noplain nologin starttls insecure oauthbearer xoauth2",
"fetchtype : TOKIMAP TOKPIPE replstrv userpass folderlist imaponly",
"fetchtype : TOKSTDIN",
"fetchtype : maildirs",
"fetchtype : mboxes",
"fetchtype : nntptype server userpassnetrc groups TOKCACHE replpathv verify insecure",
"account : TOKACCOUNT replstrv disabled users fetchtype keep",

};
#endif

#if YYDEBUG
int      yydebug;
#endif

int      yyerrflag;
int      yychar;
YYSTYPE  yyval;
YYSTYPE  yylval;
int      yynerrs;

#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
YYLTYPE  yyloc; /* position returned by actions */
YYLTYPE  yylloc; /* position from the lexer */
#endif

#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
#ifndef YYLLOC_DEFAULT
#define YYLLOC_DEFAULT(loc, rhs, n) \
do \
{ \
    if (n == 0) \
    { \
        (loc).first_line   = YYRHSLOC(rhs, 0).last_line; \
        (loc).first_column = YYRHSLOC(rhs, 0).last_column; \
        (loc).last_line    = YYRHSLOC(rhs, 0).last_line; \
        (loc).last_column  = YYRHSLOC(rhs, 0).last_column; \
    } \
    else \
    { \
        (loc).first_line   = YYRHSLOC(rhs, 1).first_line; \
        (loc).first_column = YYRHSLOC(rhs, 1).first_column; \
        (loc).last_line    = YYRHSLOC(rhs, n).last_line; \
        (loc).last_column  = YYRHSLOC(rhs, n).last_column; \
    } \
} while (0)
#endif /* YYLLOC_DEFAULT */
#endif /* defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED) */
#if YYBTYACC

#ifndef YYLVQUEUEGROWTH
#define YYLVQUEUEGROWTH 32
#endif
#endif /* YYBTYACC */

/* define the initial stack-sizes */
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH  YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH  10000
#endif
#endif

#ifndef YYINITSTACKSIZE
#define YYINITSTACKSIZE 200
#endif

typedef struct {
    unsigned stacksize;
    YYINT    *s_base;
    YYINT    *s_mark;
    YYINT    *s_last;
    YYSTYPE  *l_base;
    YYSTYPE  *l_mark;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    YYLTYPE  *p_base;
    YYLTYPE  *p_mark;
#endif
} YYSTACKDATA;
#if YYBTYACC

struct YYParseState_s
{
    struct YYParseState_s *save;    /* Previously saved parser state */
    YYSTACKDATA            yystack; /* saved parser stack */
    int                    state;   /* saved parser state */
    int                    errflag; /* saved error recovery status */
    int                    lexeme;  /* saved index of the conflict lexeme in the lexical queue */
    YYINT                  ctry;    /* saved index in yyctable[] for this conflict */
};
typedef struct YYParseState_s YYParseState;
#endif /* YYBTYACC */
/* variables for the parser stack */
static YYSTACKDATA yystack;
#if YYBTYACC

/* Current parser state */
static YYParseState *yyps = 0;

/* yypath != NULL: do the full parse, starting at *yypath parser state. */
static YYParseState *yypath = 0;

/* Base of the lexical value queue */
static YYSTYPE *yylvals = 0;

/* Current position at lexical value queue */
static YYSTYPE *yylvp = 0;

/* End position of lexical value queue */
static YYSTYPE *yylve = 0;

/* The last allocated position at the lexical value queue */
static YYSTYPE *yylvlim = 0;

#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
/* Base of the lexical position queue */
static YYLTYPE *yylpsns = 0;

/* Current position at lexical position queue */
static YYLTYPE *yylpp = 0;

/* End position of lexical position queue */
static YYLTYPE *yylpe = 0;

/* The last allocated position at the lexical position queue */
static YYLTYPE *yylplim = 0;
#endif

/* Current position at lexical token queue */
static YYINT  *yylexp = 0;

static YYINT  *yylexemes = 0;
#endif /* YYBTYACC */
#line 2495 "parse.y"

/* Programs */
#line 2612 "parse.c"

/* For use in generated program */
#define yydepth (int)(yystack.s_mark - yystack.s_base)
#if YYBTYACC
#define yytrial (yyps->save)
#endif /* YYBTYACC */

#if YYDEBUG
#include <stdio.h>	/* needed for printf */
#endif

#include <stdlib.h>	/* needed for malloc, etc */
#include <string.h>	/* needed for memset */

/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack(YYSTACKDATA *data)
{
    int i;
    unsigned newsize;
    YYINT *newss;
    YYSTYPE *newvs;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    YYLTYPE *newps;
#endif

    if ((newsize = data->stacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return YYENOMEM;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;

    i = (int) (data->s_mark - data->s_base);
    newss = (YYINT *)realloc(data->s_base, newsize * sizeof(*newss));
    if (newss == 0)
        return YYENOMEM;

    data->s_base = newss;
    data->s_mark = newss + i;

    newvs = (YYSTYPE *)realloc(data->l_base, newsize * sizeof(*newvs));
    if (newvs == 0)
        return YYENOMEM;

    data->l_base = newvs;
    data->l_mark = newvs + i;

#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    newps = (YYLTYPE *)realloc(data->p_base, newsize * sizeof(*newps));
    if (newps == 0)
        return YYENOMEM;

    data->p_base = newps;
    data->p_mark = newps + i;
#endif

    data->stacksize = newsize;
    data->s_last = data->s_base + newsize - 1;

#if YYDEBUG
    if (yydebug)
        fprintf(stderr, "%sdebug: stack size increased to %d\n", YYPREFIX, newsize);
#endif
    return 0;
}

#if YYPURE || defined(YY_NO_LEAKS)
static void yyfreestack(YYSTACKDATA *data)
{
    free(data->s_base);
    free(data->l_base);
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    free(data->p_base);
#endif
    memset(data, 0, sizeof(*data));
}
#else
#define yyfreestack(data) /* nothing */
#endif /* YYPURE || defined(YY_NO_LEAKS) */
#if YYBTYACC

static YYParseState *
yyNewState(unsigned size)
{
    YYParseState *p = (YYParseState *) malloc(sizeof(YYParseState));
    if (p == NULL) return NULL;

    p->yystack.stacksize = size;
    if (size == 0)
    {
        p->yystack.s_base = NULL;
        p->yystack.l_base = NULL;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
        p->yystack.p_base = NULL;
#endif
        return p;
    }
    p->yystack.s_base    = (YYINT *) malloc(size * sizeof(YYINT));
    if (p->yystack.s_base == NULL) return NULL;
    p->yystack.l_base    = (YYSTYPE *) malloc(size * sizeof(YYSTYPE));
    if (p->yystack.l_base == NULL) return NULL;
    memset(p->yystack.l_base, 0, size * sizeof(YYSTYPE));
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    p->yystack.p_base    = (YYLTYPE *) malloc(size * sizeof(YYLTYPE));
    if (p->yystack.p_base == NULL) return NULL;
    memset(p->yystack.p_base, 0, size * sizeof(YYLTYPE));
#endif

    return p;
}

static void
yyFreeState(YYParseState *p)
{
    yyfreestack(&p->yystack);
    free(p);
}
#endif /* YYBTYACC */

#define YYABORT  goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR  goto yyerrlab
#if YYBTYACC
#define YYVALID        do { if (yyps->save)            goto yyvalid; } while(0)
#define YYVALID_NESTED do { if (yyps->save && \
                                yyps->save->save == 0) goto yyvalid; } while(0)
#endif /* YYBTYACC */

int
YYPARSE_DECL()
{
    int yym, yyn, yystate, yyresult;
#if YYBTYACC
    int yynewerrflag;
    YYParseState *yyerrctx = NULL;
#endif /* YYBTYACC */
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    YYLTYPE  yyerror_loc_range[3]; /* position of error start/end (0 unused) */
#endif
#if YYDEBUG
    const char *yys;

    if ((yys = getenv("YYDEBUG")) != 0)
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
    if (yydebug)
        fprintf(stderr, "%sdebug[<# of symbols on state stack>]\n", YYPREFIX);
#endif
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    memset(yyerror_loc_range, 0, sizeof(yyerror_loc_range));
#endif

#if YYBTYACC
    yyps = yyNewState(0); if (yyps == 0) goto yyenomem;
    yyps->save = 0;
#endif /* YYBTYACC */
    yym = 0;
    /* yyn is set below */
    yynerrs = 0;
    yyerrflag = 0;
    yychar = YYEMPTY;
    yystate = 0;

#if YYPURE
    memset(&yystack, 0, sizeof(yystack));
#endif

    if (yystack.s_base == NULL && yygrowstack(&yystack) == YYENOMEM) goto yyoverflow;
    yystack.s_mark = yystack.s_base;
    yystack.l_mark = yystack.l_base;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    yystack.p_mark = yystack.p_base;
#endif
    yystate = 0;
    *yystack.s_mark = 0;

yyloop:
    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
    if (yychar < 0)
    {
#if YYBTYACC
        do {
        if (yylvp < yylve)
        {
            /* we're currently re-reading tokens */
            yylval = *yylvp++;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            yylloc = *yylpp++;
#endif
            yychar = *yylexp++;
            break;
        }
        if (yyps->save)
        {
            /* in trial mode; save scanner results for future parse attempts */
            if (yylvp == yylvlim)
            {   /* Enlarge lexical value queue */
                size_t p = (size_t) (yylvp - yylvals);
                size_t s = (size_t) (yylvlim - yylvals);

                s += YYLVQUEUEGROWTH;
                if ((yylexemes = (YYINT *)realloc(yylexemes, s * sizeof(YYINT))) == NULL) goto yyenomem;
                if ((yylvals   = (YYSTYPE *)realloc(yylvals, s * sizeof(YYSTYPE))) == NULL) goto yyenomem;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                if ((yylpsns   = (YYLTYPE *)realloc(yylpsns, s * sizeof(YYLTYPE))) == NULL) goto yyenomem;
#endif
                yylvp   = yylve = yylvals + p;
                yylvlim = yylvals + s;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                yylpp   = yylpe = yylpsns + p;
                yylplim = yylpsns + s;
#endif
                yylexp  = yylexemes + p;
            }
            *yylexp = (YYINT) YYLEX;
            *yylvp++ = yylval;
            yylve++;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            *yylpp++ = yylloc;
            yylpe++;
#endif
            yychar = *yylexp++;
            break;
        }
        /* normal operation, no conflict encountered */
#endif /* YYBTYACC */
        yychar = YYLEX;
#if YYBTYACC
        } while (0);
#endif /* YYBTYACC */
        if (yychar < 0) yychar = YYEOF;
#if YYDEBUG
        if (yydebug)
        {
            if ((yys = yyname[YYTRANSLATE(yychar)]) == NULL) yys = yyname[YYUNDFTOKEN];
            fprintf(stderr, "%s[%d]: state %d, reading token %d (%s)",
                            YYDEBUGSTR, yydepth, yystate, yychar, yys);
#ifdef YYSTYPE_TOSTRING
#if YYBTYACC
            if (!yytrial)
#endif /* YYBTYACC */
                fprintf(stderr, " <%s>", YYSTYPE_TOSTRING(yychar, yylval));
#endif
            fputc('\n', stderr);
        }
#endif
    }
#if YYBTYACC

    /* Do we have a conflict? */
    if (((yyn = yycindex[yystate]) != 0) && (yyn += yychar) >= 0 &&
        yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) yychar)
    {
        YYINT ctry;

        if (yypath)
        {
            YYParseState *save;
#if YYDEBUG
            if (yydebug)
                fprintf(stderr, "%s[%d]: CONFLICT in state %d: following successful trial parse\n",
                                YYDEBUGSTR, yydepth, yystate);
#endif
            /* Switch to the next conflict context */
            save = yypath;
            yypath = save->save;
            save->save = NULL;
            ctry = save->ctry;
            if (save->state != yystate) YYABORT;
            yyFreeState(save);

        }
        else
        {

            /* Unresolved conflict - start/continue trial parse */
            YYParseState *save;
#if YYDEBUG
            if (yydebug)
            {
                fprintf(stderr, "%s[%d]: CONFLICT in state %d. ", YYDEBUGSTR, yydepth, yystate);
                if (yyps->save)
                    fputs("ALREADY in conflict, continuing trial parse.\n", stderr);
                else
                    fputs("Starting trial parse.\n", stderr);
            }
#endif
            save                  = yyNewState((unsigned)(yystack.s_mark - yystack.s_base + 1));
            if (save == NULL) goto yyenomem;
            save->save            = yyps->save;
            save->state           = yystate;
            save->errflag         = yyerrflag;
            save->yystack.s_mark  = save->yystack.s_base + (yystack.s_mark - yystack.s_base);
            memcpy (save->yystack.s_base, yystack.s_base, (size_t) (yystack.s_mark - yystack.s_base + 1) * sizeof(YYINT));
            save->yystack.l_mark  = save->yystack.l_base + (yystack.l_mark - yystack.l_base);
            memcpy (save->yystack.l_base, yystack.l_base, (size_t) (yystack.l_mark - yystack.l_base + 1) * sizeof(YYSTYPE));
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            save->yystack.p_mark  = save->yystack.p_base + (yystack.p_mark - yystack.p_base);
            memcpy (save->yystack.p_base, yystack.p_base, (size_t) (yystack.p_mark - yystack.p_base + 1) * sizeof(YYLTYPE));
#endif
            ctry                  = yytable[yyn];
            if (yyctable[ctry] == -1)
            {
#if YYDEBUG
                if (yydebug && yychar >= YYEOF)
                    fprintf(stderr, "%s[%d]: backtracking 1 token\n", YYDEBUGSTR, yydepth);
#endif
                ctry++;
            }
            save->ctry = ctry;
            if (yyps->save == NULL)
            {
                /* If this is a first conflict in the stack, start saving lexemes */
                if (!yylexemes)
                {
                    yylexemes = (YYINT *) malloc((YYLVQUEUEGROWTH) * sizeof(YYINT));
                    if (yylexemes == NULL) goto yyenomem;
                    yylvals   = (YYSTYPE *) malloc((YYLVQUEUEGROWTH) * sizeof(YYSTYPE));
                    if (yylvals == NULL) goto yyenomem;
                    yylvlim   = yylvals + YYLVQUEUEGROWTH;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                    yylpsns   = (YYLTYPE *) malloc((YYLVQUEUEGROWTH) * sizeof(YYLTYPE));
                    if (yylpsns == NULL) goto yyenomem;
                    yylplim   = yylpsns + YYLVQUEUEGROWTH;
#endif
                }
                if (yylvp == yylve)
                {
                    yylvp  = yylve = yylvals;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                    yylpp  = yylpe = yylpsns;
#endif
                    yylexp = yylexemes;
                    if (yychar >= YYEOF)
                    {
                        *yylve++ = yylval;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                        *yylpe++ = yylloc;
#endif
                        *yylexp  = (YYINT) yychar;
                        yychar   = YYEMPTY;
                    }
                }
            }
            if (yychar >= YYEOF)
            {
                yylvp--;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                yylpp--;
#endif
                yylexp--;
                yychar = YYEMPTY;
            }
            save->lexeme = (int) (yylvp - yylvals);
            yyps->save   = save;
        }
        if (yytable[yyn] == ctry)
        {
#if YYDEBUG
            if (yydebug)
                fprintf(stderr, "%s[%d]: state %d, shifting to state %d\n",
                                YYDEBUGSTR, yydepth, yystate, yyctable[ctry]);
#endif
            if (yychar < 0)
            {
                yylvp++;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                yylpp++;
#endif
                yylexp++;
            }
            if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack) == YYENOMEM)
                goto yyoverflow;
            yystate = yyctable[ctry];
            *++yystack.s_mark = (YYINT) yystate;
            *++yystack.l_mark = yylval;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            *++yystack.p_mark = yylloc;
#endif
            yychar  = YYEMPTY;
            if (yyerrflag > 0) --yyerrflag;
            goto yyloop;
        }
        else
        {
            yyn = yyctable[ctry];
            goto yyreduce;
        }
    } /* End of code dealing with conflicts */
#endif /* YYBTYACC */
    if (((yyn = yysindex[yystate]) != 0) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) yychar)
    {
#if YYDEBUG
        if (yydebug)
            fprintf(stderr, "%s[%d]: state %d, shifting to state %d\n",
                            YYDEBUGSTR, yydepth, yystate, yytable[yyn]);
#endif
        if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack) == YYENOMEM) goto yyoverflow;
        yystate = yytable[yyn];
        *++yystack.s_mark = yytable[yyn];
        *++yystack.l_mark = yylval;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
        *++yystack.p_mark = yylloc;
#endif
        yychar = YYEMPTY;
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if (((yyn = yyrindex[yystate]) != 0) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag != 0) goto yyinrecovery;
#if YYBTYACC

    yynewerrflag = 1;
    goto yyerrhandler;
    goto yyerrlab; /* redundant goto avoids 'unused label' warning */

yyerrlab:
    /* explicit YYERROR from an action -- pop the rhs of the rule reduced
     * before looking for error recovery */
    yystack.s_mark -= yym;
    yystate = *yystack.s_mark;
    yystack.l_mark -= yym;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    yystack.p_mark -= yym;
#endif

    yynewerrflag = 0;
yyerrhandler:
    while (yyps->save)
    {
        int ctry;
        YYParseState *save = yyps->save;
#if YYDEBUG
        if (yydebug)
            fprintf(stderr, "%s[%d]: ERROR in state %d, CONFLICT BACKTRACKING to state %d, %d tokens\n",
                            YYDEBUGSTR, yydepth, yystate, yyps->save->state,
                    (int)(yylvp - yylvals - yyps->save->lexeme));
#endif
        /* Memorize most forward-looking error state in case it's really an error. */
        if (yyerrctx == NULL || yyerrctx->lexeme < yylvp - yylvals)
        {
            /* Free old saved error context state */
            if (yyerrctx) yyFreeState(yyerrctx);
            /* Create and fill out new saved error context state */
            yyerrctx                 = yyNewState((unsigned)(yystack.s_mark - yystack.s_base + 1));
            if (yyerrctx == NULL) goto yyenomem;
            yyerrctx->save           = yyps->save;
            yyerrctx->state          = yystate;
            yyerrctx->errflag        = yyerrflag;
            yyerrctx->yystack.s_mark = yyerrctx->yystack.s_base + (yystack.s_mark - yystack.s_base);
            memcpy (yyerrctx->yystack.s_base, yystack.s_base, (size_t) (yystack.s_mark - yystack.s_base + 1) * sizeof(YYINT));
            yyerrctx->yystack.l_mark = yyerrctx->yystack.l_base + (yystack.l_mark - yystack.l_base);
            memcpy (yyerrctx->yystack.l_base, yystack.l_base, (size_t) (yystack.l_mark - yystack.l_base + 1) * sizeof(YYSTYPE));
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            yyerrctx->yystack.p_mark = yyerrctx->yystack.p_base + (yystack.p_mark - yystack.p_base);
            memcpy (yyerrctx->yystack.p_base, yystack.p_base, (size_t) (yystack.p_mark - yystack.p_base + 1) * sizeof(YYLTYPE));
#endif
            yyerrctx->lexeme         = (int) (yylvp - yylvals);
        }
        yylvp          = yylvals   + save->lexeme;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
        yylpp          = yylpsns   + save->lexeme;
#endif
        yylexp         = yylexemes + save->lexeme;
        yychar         = YYEMPTY;
        yystack.s_mark = yystack.s_base + (save->yystack.s_mark - save->yystack.s_base);
        memcpy (yystack.s_base, save->yystack.s_base, (size_t) (yystack.s_mark - yystack.s_base + 1) * sizeof(YYINT));
        yystack.l_mark = yystack.l_base + (save->yystack.l_mark - save->yystack.l_base);
        memcpy (yystack.l_base, save->yystack.l_base, (size_t) (yystack.l_mark - yystack.l_base + 1) * sizeof(YYSTYPE));
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
        yystack.p_mark = yystack.p_base + (save->yystack.p_mark - save->yystack.p_base);
        memcpy (yystack.p_base, save->yystack.p_base, (size_t) (yystack.p_mark - yystack.p_base + 1) * sizeof(YYLTYPE));
#endif
        ctry           = ++save->ctry;
        yystate        = save->state;
        /* We tried shift, try reduce now */
        if ((yyn = yyctable[ctry]) >= 0) goto yyreduce;
        yyps->save     = save->save;
        save->save     = NULL;
        yyFreeState(save);

        /* Nothing left on the stack -- error */
        if (!yyps->save)
        {
#if YYDEBUG
            if (yydebug)
                fprintf(stderr, "%sdebug[%d,trial]: trial parse FAILED, entering ERROR mode\n",
                                YYPREFIX, yydepth);
#endif
            /* Restore state as it was in the most forward-advanced error */
            yylvp          = yylvals   + yyerrctx->lexeme;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            yylpp          = yylpsns   + yyerrctx->lexeme;
#endif
            yylexp         = yylexemes + yyerrctx->lexeme;
            yychar         = yylexp[-1];
            yylval         = yylvp[-1];
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            yylloc         = yylpp[-1];
#endif
            yystack.s_mark = yystack.s_base + (yyerrctx->yystack.s_mark - yyerrctx->yystack.s_base);
            memcpy (yystack.s_base, yyerrctx->yystack.s_base, (size_t) (yystack.s_mark - yystack.s_base + 1) * sizeof(YYINT));
            yystack.l_mark = yystack.l_base + (yyerrctx->yystack.l_mark - yyerrctx->yystack.l_base);
            memcpy (yystack.l_base, yyerrctx->yystack.l_base, (size_t) (yystack.l_mark - yystack.l_base + 1) * sizeof(YYSTYPE));
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            yystack.p_mark = yystack.p_base + (yyerrctx->yystack.p_mark - yyerrctx->yystack.p_base);
            memcpy (yystack.p_base, yyerrctx->yystack.p_base, (size_t) (yystack.p_mark - yystack.p_base + 1) * sizeof(YYLTYPE));
#endif
            yystate        = yyerrctx->state;
            yyFreeState(yyerrctx);
            yyerrctx       = NULL;
        }
        yynewerrflag = 1;
    }
    if (yynewerrflag == 0) goto yyinrecovery;
#endif /* YYBTYACC */

    YYERROR_CALL("syntax error");
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    yyerror_loc_range[1] = yylloc; /* lookahead position is error start position */
#endif

#if !YYBTYACC
    goto yyerrlab; /* redundant goto avoids 'unused label' warning */
yyerrlab:
#endif
    ++yynerrs;

yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if (((yyn = yysindex[*yystack.s_mark]) != 0) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    fprintf(stderr, "%s[%d]: state %d, error recovery shifting to state %d\n",
                                    YYDEBUGSTR, yydepth, *yystack.s_mark, yytable[yyn]);
#endif
                if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack) == YYENOMEM) goto yyoverflow;
                yystate = yytable[yyn];
                *++yystack.s_mark = yytable[yyn];
                *++yystack.l_mark = yylval;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                /* lookahead position is error end position */
                yyerror_loc_range[2] = yylloc;
                YYLLOC_DEFAULT(yyloc, yyerror_loc_range, 2); /* position of error span */
                *++yystack.p_mark = yyloc;
#endif
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    fprintf(stderr, "%s[%d]: error recovery discarding state %d\n",
                                    YYDEBUGSTR, yydepth, *yystack.s_mark);
#endif
                if (yystack.s_mark <= yystack.s_base) goto yyabort;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                /* the current TOS position is the error start position */
                yyerror_loc_range[1] = *yystack.p_mark;
#endif
#if defined(YYDESTRUCT_CALL)
#if YYBTYACC
                if (!yytrial)
#endif /* YYBTYACC */
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                    YYDESTRUCT_CALL("error: discarding state",
                                    yystos[*yystack.s_mark], yystack.l_mark, yystack.p_mark);
#else
                    YYDESTRUCT_CALL("error: discarding state",
                                    yystos[*yystack.s_mark], yystack.l_mark);
#endif /* defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED) */
#endif /* defined(YYDESTRUCT_CALL) */
                --yystack.s_mark;
                --yystack.l_mark;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                --yystack.p_mark;
#endif
            }
        }
    }
    else
    {
        if (yychar == YYEOF) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            if ((yys = yyname[YYTRANSLATE(yychar)]) == NULL) yys = yyname[YYUNDFTOKEN];
            fprintf(stderr, "%s[%d]: state %d, error recovery discarding token %d (%s)\n",
                            YYDEBUGSTR, yydepth, yystate, yychar, yys);
        }
#endif
#if defined(YYDESTRUCT_CALL)
#if YYBTYACC
        if (!yytrial)
#endif /* YYBTYACC */
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
            YYDESTRUCT_CALL("error: discarding token", yychar, &yylval, &yylloc);
#else
            YYDESTRUCT_CALL("error: discarding token", yychar, &yylval);
#endif /* defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED) */
#endif /* defined(YYDESTRUCT_CALL) */
        yychar = YYEMPTY;
        goto yyloop;
    }

yyreduce:
    yym = yylen[yyn];
#if YYDEBUG
    if (yydebug)
    {
        fprintf(stderr, "%s[%d]: state %d, reducing by rule %d (%s)",
                        YYDEBUGSTR, yydepth, yystate, yyn, yyrule[yyn]);
#ifdef YYSTYPE_TOSTRING
#if YYBTYACC
        if (!yytrial)
#endif /* YYBTYACC */
            if (yym > 0)
            {
                int i;
                fputc('<', stderr);
                for (i = yym; i > 0; i--)
                {
                    if (i != yym) fputs(", ", stderr);
                    fputs(YYSTYPE_TOSTRING(yystos[yystack.s_mark[1-i]],
                                           yystack.l_mark[1-i]), stderr);
                }
                fputc('>', stderr);
            }
#endif
        fputc('\n', stderr);
    }
#endif
    if (yym > 0)
        yyval = yystack.l_mark[1-yym];
    else
        memset(&yyval, 0, sizeof yyval);
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)

    /* Perform position reduction */
    memset(&yyloc, 0, sizeof(yyloc));
#if YYBTYACC
    if (!yytrial)
#endif /* YYBTYACC */
    {
        YYLLOC_DEFAULT(yyloc, &yystack.p_mark[-yym], yym);
        /* just in case YYERROR is invoked within the action, save
           the start of the rhs as the error start position */
        yyerror_loc_range[1] = yystack.p_mark[1-yym];
    }
#endif

    switch (yyn)
    {
case 26:
#line 364 "parse.y"
	{
	     yyval.string = yystack.l_mark[0].string;
     }
#line 3287 "parse.c"
break;
case 27:
#line 368 "parse.y"
	{
	     yyval.string = yystack.l_mark[0].string;
     }
#line 3294 "parse.c"
break;
case 28:
#line 373 "parse.y"
	{
		yyval.string = yystack.l_mark[0].string;
	}
#line 3301 "parse.c"
break;
case 29:
#line 377 "parse.y"
	{
		yyval.string = NULL;
	}
#line 3308 "parse.c"
break;
case 30:
#line 382 "parse.y"
	{
	       yyval.string = run_command(yystack.l_mark[0].string, parse_file->path);
	       xfree(yystack.l_mark[0].string);
       }
#line 3316 "parse.c"
break;
case 31:
#line 387 "parse.y"
	{
	       yyval.string = yystack.l_mark[0].string;
       }
#line 3323 "parse.c"
break;
case 32:
#line 391 "parse.y"
	{
	       struct macro	*macro;

	       if (strlen(yystack.l_mark[0].string) > MAXNAMESIZE)
		       yyerror("macro name too long: %s", yystack.l_mark[0].string);

	       if ((macro = find_macro(yystack.l_mark[0].string)) == NULL)
		       yyerror("undefined macro: %s", yystack.l_mark[0].string);
	       if (macro->type != MACRO_STRING)
		       yyerror("string macro expected: %s", yystack.l_mark[0].string);

	       yyval.string = xstrdup(macro->value.str);

	       xfree(yystack.l_mark[0].string);
       }
#line 3342 "parse.c"
break;
case 33:
#line 408 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
#line 3349 "parse.c"
break;
case 34:
#line 412 "parse.y"
	{
	      size_t	size;

	      size = strlen(yystack.l_mark[-2].string) + strlen(yystack.l_mark[0].string) + 1;
	      yyval.string = xrealloc(yystack.l_mark[-2].string, 1, size);
	      strlcat(yyval.string, yystack.l_mark[0].string, size);
	      xfree(yystack.l_mark[0].string);
      }
#line 3361 "parse.c"
break;
case 35:
#line 422 "parse.y"
	{
	      const char	*errstr;
	      char		*s;

	      s = run_command(yystack.l_mark[0].string, parse_file->path);

	      yyval.number = strtonum(s, 0, LLONG_MAX, &errstr);
	      if (errstr != NULL)
		      yyerror("number is %s", errstr);

	      xfree(s);

	      xfree(yystack.l_mark[0].string);
      }
#line 3379 "parse.c"
break;
case 36:
#line 437 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
#line 3386 "parse.c"
break;
case 37:
#line 441 "parse.y"
	{
	      struct macro	*macro;

	      if (strlen(yystack.l_mark[0].string) > MAXNAMESIZE)
		      yyerror("macro name too long: %s", yystack.l_mark[0].string);

	      if ((macro = find_macro(yystack.l_mark[0].string)) == NULL)
		      yyerror("undefined macro: %s", yystack.l_mark[0].string);
	      if (macro->type != MACRO_NUMBER)
		      yyerror("number macro expected: %s", yystack.l_mark[0].string);

	      yyval.number = macro->value.num;

	      xfree(yystack.l_mark[0].string);
      }
#line 3405 "parse.c"
break;
case 38:
#line 458 "parse.y"
	{
		  struct replstr	 rs;
		  struct userdata	*ud;

		  if ((ud = user_lookup(conf.def_user, conf.user_order)) != NULL)
			  update_tags(&parse_tags, ud);
		  rs.str = yystack.l_mark[0].string;
		  yyval.string = replacestr(&rs, parse_tags, NULL, NULL);
		  xfree(yystack.l_mark[0].string);
	  }
#line 3419 "parse.c"
break;
case 39:
#line 470 "parse.y"
	{
		  struct replpath	 rp;
		  struct userdata	*ud;

		  if ((ud = user_lookup(conf.def_user, conf.user_order)) != NULL)
			  update_tags(&parse_tags, ud);
		  rp.str = yystack.l_mark[0].string;
		  yyval.string = replacepath(&rp, parse_tags, NULL, NULL, conf.user_home);
		  xfree(yystack.l_mark[0].string);
	   }
#line 3433 "parse.c"
break;
case 40:
#line 482 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
#line 3440 "parse.c"
break;
case 41:
#line 486 "parse.y"
	{
	      yyval.number = yystack.l_mark[-1].number;
      }
#line 3447 "parse.c"
break;
case 42:
#line 490 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / 1024)
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * 1024;
      }
#line 3456 "parse.c"
break;
case 43:
#line 496 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / (1024 * 1024))
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * (1024 * 1024);
      }
#line 3465 "parse.c"
break;
case 44:
#line 502 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / (1024 * 1024 * 1024))
		      yyerror("size is too big");
	      yyval.number = yystack.l_mark[-1].number * (1024 * 1024 * 1024);
      }
#line 3474 "parse.c"
break;
case 45:
#line 509 "parse.y"
	{
	      yyval.number = yystack.l_mark[0].number;
      }
#line 3481 "parse.c"
break;
case 46:
#line 513 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_HOUR)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_HOUR;
      }
#line 3490 "parse.c"
break;
case 47:
#line 519 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_MINUTE)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_MINUTE;
      }
#line 3499 "parse.c"
break;
case 48:
#line 525 "parse.y"
	{
	      yyval.number = yystack.l_mark[-1].number;
      }
#line 3506 "parse.c"
break;
case 49:
#line 529 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_DAY)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_DAY;
      }
#line 3515 "parse.c"
break;
case 50:
#line 535 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_WEEK)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_WEEK;
      }
#line 3524 "parse.c"
break;
case 51:
#line 541 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_MONTH)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_MONTH;
      }
#line 3533 "parse.c"
break;
case 52:
#line 547 "parse.y"
	{
	      if (yystack.l_mark[-1].number > LLONG_MAX / TIME_YEAR)
		      yyerror("time is too long");
	      yyval.number = yystack.l_mark[-1].number * TIME_YEAR;
      }
#line 3542 "parse.c"
break;
case 53:
#line 554 "parse.y"
	{
#if UINT64_MAX < LLONG_MAX
		if (yystack.l_mark[0].number > UINT64_MAX)
			yyerror("time too long");
#endif

		yyval.number = yystack.l_mark[0].number;
	}
#line 3554 "parse.c"
break;
case 54:
#line 563 "parse.y"
	{
		yyval.number = -1;
	}
#line 3561 "parse.c"
break;
case 55:
#line 568 "parse.y"
	{
	       struct cache	*cache;

	       TAILQ_FOREACH(cache, &conf.caches, entry) {
		       if (strcmp(cache->path, yystack.l_mark[-1].string) == 0)
			       yyerror("duplicate cache path");
	       }

	       cache = xcalloc(1, sizeof *cache);
	       cache->path = yystack.l_mark[-1].string;
	       cache->expire = yystack.l_mark[0].number;

	       TAILQ_INSERT_TAIL(&conf.caches, cache, entry);

	       log_debug2("added cache \"%s\": expire %lld", cache->path, yystack.l_mark[0].number);
       }
#line 3581 "parse.c"
break;
case 56:
#line 586 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero maximum size");
	     if (yystack.l_mark[0].number > MAXMAILSIZE)
		     yyerror("maximum size too large: %lld", yystack.l_mark[0].number);
	     conf.max_size = yystack.l_mark[0].number;
     }
#line 3592 "parse.c"
break;
case 57:
#line 594 "parse.y"
	{
	     if (yystack.l_mark[0].locks & LOCK_FCNTL && yystack.l_mark[0].locks & LOCK_FLOCK)
		     yyerror("fcntl and flock locking cannot be used together");
	     conf.lock_types = yystack.l_mark[0].locks;
     }
#line 3601 "parse.c"
break;
case 58:
#line 600 "parse.y"
	{
	     if (conf.lock_file != NULL)
		     xfree(conf.lock_file);
	     conf.lock_file = yystack.l_mark[0].string;
     }
#line 3610 "parse.c"
break;
case 59:
#line 606 "parse.y"
	{
	     conf.lock_wait = 1;
     }
#line 3617 "parse.c"
break;
case 60:
#line 610 "parse.y"
	{
	     conf.lock_timeout = yystack.l_mark[0].number;
     }
#line 3624 "parse.c"
break;
case 61:
#line 614 "parse.y"
	{
	     conf.del_big = 1;
     }
#line 3631 "parse.c"
break;
case 62:
#line 618 "parse.y"
	{
	     conf.ignore_errors = 1;
     }
#line 3638 "parse.c"
break;
case 63:
#line 622 "parse.y"
	{
	     conf.allow_many = 1;
     }
#line 3645 "parse.c"
break;
case 64:
#line 626 "parse.y"
	{
	     if (conf.def_user == NULL)
		     conf.def_user = yystack.l_mark[0].string;
     }
#line 3653 "parse.c"
break;
case 65:
#line 631 "parse.y"
	{
	     if (conf.cmd_user == NULL)
		     conf.cmd_user = yystack.l_mark[0].string;
     }
#line 3661 "parse.c"
break;
case 66:
#line 636 "parse.y"
	{
	     xfree(conf.strip_chars);
	     conf.strip_chars = yystack.l_mark[0].string;
     }
#line 3669 "parse.c"
break;
case 67:
#line 641 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero timeout");
	     if (yystack.l_mark[0].number > INT_MAX / 1000)
		     yyerror("timeout too long: %lld", yystack.l_mark[0].number);
	     conf.timeout = yystack.l_mark[0].number * 1000;
     }
#line 3680 "parse.c"
break;
case 68:
#line 649 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("zero queue-high");
	     if (yystack.l_mark[0].number > MAXQUEUEVALUE)
		     yyerror("queue-high too big: %lld", yystack.l_mark[0].number);
	     if (conf.queue_low != -1 && yystack.l_mark[0].number <= conf.queue_low)
		     yyerror("queue-high must be larger than queue-low");
	     conf.queue_high = yystack.l_mark[0].number;
     }
#line 3693 "parse.c"
break;
case 69:
#line 659 "parse.y"
	{
	     if (yystack.l_mark[0].number > MAXQUEUEVALUE)
		     yyerror("queue-low too big: %lld", yystack.l_mark[0].number);
	     if (conf.queue_high == -1)
		     yyerror("queue-high not specified");
	     if (yystack.l_mark[0].number >= conf.queue_high)
		     yyerror("queue-low must be smaller than queue-high");
	     conf.queue_low = yystack.l_mark[0].number;
     }
#line 3706 "parse.c"
break;
case 70:
#line 669 "parse.y"
	{
	     if (yystack.l_mark[0].number > INT_MAX)
		     yyerror("parallel-accounts too big: %lld", yystack.l_mark[0].number);
	     if (yystack.l_mark[0].number == 0)
		     yyerror("parallel-accounts cannot be zero");
	     conf.max_accts = yystack.l_mark[0].number;
     }
#line 3717 "parse.c"
break;
case 71:
#line 677 "parse.y"
	{
	     if (conf.proxy != NULL) {
		     xfree(conf.proxy->server.host);
		     xfree(conf.proxy->server.port);
		     if (conf.proxy->user != NULL)
			     xfree(conf.proxy->user);
		     if (conf.proxy->pass != NULL)
			     xfree(conf.proxy->pass);
	     }
	     if ((conf.proxy = getproxy(yystack.l_mark[0].string)) == NULL)
		     yyerror("invalid proxy");
	     xfree(yystack.l_mark[0].string);
     }
#line 3734 "parse.c"
break;
case 72:
#line 691 "parse.y"
	{
	     conf.verify_certs = 1;
     }
#line 3741 "parse.c"
break;
case 73:
#line 695 "parse.y"
	{
	     conf.impl_act = DECISION_KEEP;
     }
#line 3748 "parse.c"
break;
case 74:
#line 699 "parse.y"
	{
	     conf.impl_act = DECISION_DROP;
     }
#line 3755 "parse.c"
break;
case 75:
#line 703 "parse.y"
	{
	     if (yystack.l_mark[0].number == 0)
		     yyerror("invalid purge-after value: 0");
	     if (yystack.l_mark[0].number > UINT_MAX)
		     yyerror("purge-after value too large: %lld", yystack.l_mark[0].number);

	     conf.purge_after = yystack.l_mark[0].number;
     }
#line 3767 "parse.c"
break;
case 76:
#line 712 "parse.y"
	{
	     conf.purge_after = 0;
     }
#line 3774 "parse.c"
break;
case 77:
#line 716 "parse.y"
	{
	     conf.no_received = 1;
     }
#line 3781 "parse.c"
break;
case 78:
#line 720 "parse.y"
	{
	     conf.no_create = 1;
     }
#line 3788 "parse.c"
break;
case 79:
#line 724 "parse.y"
	{
	     conf.file_group = -1;
     }
#line 3795 "parse.c"
break;
case 80:
#line 728 "parse.y"
	{
	     conf.file_group = yystack.l_mark[0].localgid;
     }
#line 3802 "parse.c"
break;
case 81:
#line 732 "parse.y"
	{
	     conf.file_umask = umask(0);
	     umask(conf.file_umask);
     }
#line 3810 "parse.c"
break;
case 82:
#line 737 "parse.y"
	{
	     ARRAY_FREEALL(conf.user_order);
	     conf.user_order = yystack.l_mark[0].ufns;
     }
#line 3818 "parse.c"
break;
case 83:
#line 742 "parse.y"
	{
	     char	s[8];
	     u_int	n;

	     /*
	      * We can't differentiate umasks in octal from normal numbers
	      * (requiring a leading zero a la C would be nice, but it would
	      * potentially break existing configs), so we need to fiddle to
	      * convert.
	      */
	     memset(s, 0, sizeof s);
	     xsnprintf(s, sizeof s, "%03lld", yystack.l_mark[0].number);
	     if (s[3] != '\0' || s[0] < '0' || s[0] > '7' ||
		 s[1] < 0 || s[1] > '7' || s[2] < '0' || s[2] > '7')
		     yyerror("invalid umask: %s", s);
	     if (sscanf(s, "%o", &n) != 1)
		     yyerror("invalid umask: %s", s);
	     conf.file_umask = n;
     }
#line 3841 "parse.c"
break;
case 84:
#line 763 "parse.y"
	{
		  struct macro	*macro;

		  if (strlen(yystack.l_mark[-2].string) > MAXNAMESIZE)
			  yyerror("macro name too long: %s", yystack.l_mark[-2].string);

		  macro = xmalloc(sizeof *macro);
		  strlcpy(macro->name, yystack.l_mark[-2].string, sizeof macro->name);
		  macro->type = MACRO_STRING;
		  macro->value.str = yystack.l_mark[0].string;

		  if (parse_last == NULL)
			  TAILQ_INSERT_HEAD(&parse_macros, macro, entry);
		  else {
			  TAILQ_INSERT_AFTER(
			      &parse_macros, parse_last, macro, entry);
		  }

		  log_debug3("added macro \"%s\": \"%s\"", macro->name,
		      macro->value.str);
		  xfree(yystack.l_mark[-2].string);
	  }
#line 3867 "parse.c"
break;
case 85:
#line 786 "parse.y"
	{
		  struct macro	*macro;

		  if (strlen(yystack.l_mark[-2].string) > MAXNAMESIZE)
			  yyerror("macro name too long: %s", yystack.l_mark[-2].string);

		  macro = xmalloc(sizeof *macro);
		  strlcpy(macro->name, yystack.l_mark[-2].string, sizeof macro->name);
		  macro->type = MACRO_NUMBER;
		  macro->value.num = yystack.l_mark[0].number;

		  if (parse_last == NULL)
			  TAILQ_INSERT_HEAD(&parse_macros, macro, entry);
		  else {
			  TAILQ_INSERT_AFTER(
			      &parse_macros, parse_last, macro, entry);
		  }

		  log_debug3("added macro \"%s\": %lld", macro->name,
		      macro->value.num);
		  xfree(yystack.l_mark[-2].string);
	  }
#line 3893 "parse.c"
break;
case 86:
#line 810 "parse.y"
	{
		      if (*yystack.l_mark[0].string == '\0')
			      yyerror("empty string in list");

		      yyval.replstrs = yystack.l_mark[-1].replstrs;
		      ARRAY_EXPAND(yyval.replstrs, 1);
		      ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	      }
#line 3905 "parse.c"
break;
case 87:
#line 819 "parse.y"
	{
		      if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		      yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		      ARRAY_INIT(yyval.replstrs);
		      ARRAY_EXPAND(yyval.replstrs, 1);
		      ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	      }
#line 3918 "parse.c"
break;
case 88:
#line 830 "parse.y"
	{
		     if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		     yyval.strings = yystack.l_mark[-1].strings;
		     ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	     }
#line 3929 "parse.c"
break;
case 89:
#line 838 "parse.y"
	{
		     if (*yystack.l_mark[0].string == '\0')
			     yyerror("empty string in list");

		     yyval.strings = xmalloc(sizeof *yyval.strings);
		     ARRAY_INIT(yyval.strings);
		     ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	     }
#line 3941 "parse.c"
break;
case 90:
#line 848 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid path");

		   yyval.strings = yystack.l_mark[-1].strings;
		   ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	   }
#line 3952 "parse.c"
break;
case 91:
#line 856 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid path");

		   yyval.strings = xmalloc(sizeof *yyval.strings);
		   ARRAY_INIT(yyval.strings);
		   ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	   }
#line 3964 "parse.c"
break;
case 92:
#line 866 "parse.y"
	{
	     yyval.ufn = &passwd_lookup;
     }
#line 3971 "parse.c"
break;
case 93:
#line 871 "parse.y"
	{
		 yyval.ufns = yystack.l_mark[-1].ufns;
		 ARRAY_ADD(yyval.ufns, yystack.l_mark[0].ufn);
	 }
#line 3979 "parse.c"
break;
case 94:
#line 876 "parse.y"
	{
		 yyval.ufns = xmalloc(sizeof *yyval.ufns);
		 ARRAY_INIT(yyval.ufns);
		 ARRAY_ADD(yyval.ufns, yystack.l_mark[0].ufn);
	 }
#line 3988 "parse.c"
break;
case 95:
#line 883 "parse.y"
	{
		   if (*yystack.l_mark[0].string == '\0')
			   yyerror("invalid header");

		   yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		   ARRAY_INIT(yyval.replstrs);
		   ARRAY_EXPAND(yyval.replstrs, 1);
		   ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	   }
#line 4001 "parse.c"
break;
case 96:
#line 893 "parse.y"
	{
		   yyval.replstrs = yystack.l_mark[-1].replstrs;
	   }
#line 4008 "parse.c"
break;
case 97:
#line 898 "parse.y"
	{
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid path");

		  yyval.strings = xmalloc(sizeof *yyval.strings);
		  ARRAY_INIT(yyval.strings);
		  ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	  }
#line 4020 "parse.c"
break;
case 98:
#line 907 "parse.y"
	{
		  yyval.strings = yystack.l_mark[-1].strings;
	  }
#line 4027 "parse.c"
break;
case 99:
#line 912 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid path");

		yyval.strings = xmalloc(sizeof *yyval.strings);
		ARRAY_INIT(yyval.strings);
		ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	}
#line 4039 "parse.c"
break;
case 100:
#line 921 "parse.y"
	{
		yyval.strings = yystack.l_mark[-1].strings;
	}
#line 4046 "parse.c"
break;
case 101:
#line 926 "parse.y"
	{
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid folder");

		 yyval.strings = xmalloc(sizeof *yyval.strings);
		 ARRAY_INIT(yyval.strings);
		 ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	 }
#line 4058 "parse.c"
break;
case 102:
#line 935 "parse.y"
	{
		 yyval.strings = yystack.l_mark[-1].strings;
	 }
#line 4065 "parse.c"
break;
case 103:
#line 940 "parse.y"
	{
	      yyval.locks = LOCK_FCNTL;
      }
#line 4072 "parse.c"
break;
case 104:
#line 944 "parse.y"
	{
	      yyval.locks = LOCK_FLOCK;
      }
#line 4079 "parse.c"
break;
case 105:
#line 948 "parse.y"
	{
	      yyval.locks = LOCK_DOTLOCK;
      }
#line 4086 "parse.c"
break;
case 106:
#line 953 "parse.y"
	{
		  yyval.locks = yystack.l_mark[-1].locks | yystack.l_mark[0].locks;
	  }
#line 4093 "parse.c"
break;
case 107:
#line 957 "parse.y"
	{
		  yyval.locks = yystack.l_mark[0].locks;
	  }
#line 4100 "parse.c"
break;
case 108:
#line 961 "parse.y"
	{
		  yyval.locks = 0;
	  }
#line 4107 "parse.c"
break;
case 109:
#line 966 "parse.y"
	{
		  struct group	*gr;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid group");

		  gr = getgrnam(yystack.l_mark[0].string);
		  if (gr == NULL)
			  yyerror("unknown group: %s", yystack.l_mark[0].string);
		  yyval.localgid = gr->gr_gid;
		  endgrent();

		  xfree(yystack.l_mark[0].string);
	  }
#line 4125 "parse.c"
break;
case 110:
#line 981 "parse.y"
	{
		  struct group	*gr;

		  if (yystack.l_mark[0].number > GID_MAX)
			  yyerror("invalid gid: %llu", yystack.l_mark[0].number);
		  gr = getgrgid(yystack.l_mark[0].number);
		  if (gr == NULL)
			  yyerror("unknown gid: %llu", yystack.l_mark[0].number);
		  yyval.localgid = gr->gr_gid;
		  endgrent();
	  }
#line 4140 "parse.c"
break;
case 111:
#line 994 "parse.y"
	{
	      yyval.string = NULL;
      }
#line 4147 "parse.c"
break;
case 112:
#line 998 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
#line 4154 "parse.c"
break;
case 113:
#line 1003 "parse.y"
	{
	       yyval.replstrs = NULL;
       }
#line 4161 "parse.c"
break;
case 114:
#line 1007 "parse.y"
	{
	       yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
	       ARRAY_INIT(yyval.replstrs);
	       ARRAY_EXPAND(yyval.replstrs, 1);
	       ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
       }
#line 4171 "parse.c"
break;
case 115:
#line 1014 "parse.y"
	{
	       yyval.replstrs = yystack.l_mark[-1].replstrs;
       }
#line 4178 "parse.c"
break;
case 116:
#line 1019 "parse.y"
	{
		/* match case */
		yyval.re.flags = 0;
		yyval.re.str = yystack.l_mark[0].string;
	}
#line 4187 "parse.c"
break;
case 117:
#line 1025 "parse.y"
	{
		/* ignore case */
		yyval.re.flags = RE_IGNCASE;
		yyval.re.str = yystack.l_mark[0].string;
	}
#line 4196 "parse.c"
break;
case 118:
#line 1032 "parse.y"
	{
	      yyval.flag = 1;
      }
#line 4203 "parse.c"
break;
case 119:
#line 1036 "parse.y"
	{
	      yyval.flag = 0;
      }
#line 4210 "parse.c"
break;
case 120:
#line 1041 "parse.y"
	{
	      yyval.flag = 1;
      }
#line 4217 "parse.c"
break;
case 121:
#line 1045 "parse.y"
	{
	      yyval.flag = 0;
      }
#line 4224 "parse.c"
break;
case 122:
#line 1050 "parse.y"
	{
		  yyval.flag = 1;
	  }
#line 4231 "parse.c"
break;
case 123:
#line 1054 "parse.y"
	{
		  yyval.flag = 0;
	  }
#line 4238 "parse.c"
break;
case 124:
#line 1059 "parse.y"
	{
	      if (*yystack.l_mark[0].string == '\0')
		      yyerror("invalid port");

	      yyval.string = yystack.l_mark[0].string;
      }
#line 4248 "parse.c"
break;
case 125:
#line 1066 "parse.y"
	{
	      if (yystack.l_mark[0].number == 0 || yystack.l_mark[0].number > 65535)
		      yyerror("invalid port");

	      xasprintf(&yyval.string, "%lld", yystack.l_mark[0].number);
      }
#line 4258 "parse.c"
break;
case 126:
#line 1074 "parse.y"
	{
		if (*yystack.l_mark[-1].string == '\0')
			yyerror("invalid host");

		yyval.server.host = yystack.l_mark[-1].string;
		yyval.server.port = yystack.l_mark[0].string;
	}
#line 4269 "parse.c"
break;
case 127:
#line 1082 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid host");

		yyval.server.host = yystack.l_mark[0].string;
		yyval.server.port = NULL;
	}
#line 4280 "parse.c"
break;
case 128:
#line 1091 "parse.y"
	{
	    yyval.string = NULL;
    }
#line 4287 "parse.c"
break;
case 129:
#line 1095 "parse.y"
	{
	    yyval.string = yystack.l_mark[0].string;
    }
#line 4294 "parse.c"
break;
case 130:
#line 1100 "parse.y"
	{
	      yyval.string = NULL;
      }
#line 4301 "parse.c"
break;
case 131:
#line 1104 "parse.y"
	{
	      yyval.string = yystack.l_mark[0].string;
      }
#line 4308 "parse.c"
break;
case 132:
#line 1109 "parse.y"
	{
		  yyval.flag = 1;
	  }
#line 4315 "parse.c"
break;
case 133:
#line 1113 "parse.y"
	{
		  yyval.flag = 0;
	  }
#line 4322 "parse.c"
break;
case 134:
#line 1118 "parse.y"
	{
		 struct deliver_pipe_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid command");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_pipe;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->pipe = yystack.l_mark[-1].flag;
		 data->cmd.str = yystack.l_mark[0].string;
	 }
#line 4341 "parse.c"
break;
case 135:
#line 1134 "parse.y"
	{
		 struct deliver_rewrite_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid command");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_rewrite;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->cmd.str = yystack.l_mark[0].string;
	 }
#line 4359 "parse.c"
break;
case 136:
#line 1149 "parse.y"
	{
		 struct deliver_write_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_write;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->append = yystack.l_mark[-1].flag;
		 data->path.str = yystack.l_mark[0].string;
	 }
#line 4378 "parse.c"
break;
case 137:
#line 1165 "parse.y"
	{
		 struct deliver_maildir_data	*data;

		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_maildir;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->path.str = yystack.l_mark[0].string;
	 }
#line 4396 "parse.c"
break;
case 138:
#line 1180 "parse.y"
	{
		 struct deliver_remove_header_data *data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_remove_header;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->hdrs = yystack.l_mark[0].replstrs;
	 }
#line 4411 "parse.c"
break;
case 139:
#line 1192 "parse.y"
	{
		 struct deliver_add_header_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid header");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_add_header;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->hdr.str = yystack.l_mark[-1].string;
		 data->value.str = yystack.l_mark[0].string;
	 }
#line 4430 "parse.c"
break;
case 140:
#line 1208 "parse.y"
	{
		 struct deliver_mbox_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid path");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_mbox;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->path.str = yystack.l_mark[-1].string;
		 data->compress = yystack.l_mark[0].flag;
	 }
#line 4449 "parse.c"
break;
case 141:
#line 1225 "parse.y"
	{
		 struct deliver_imap_data	*data;

		 if (yystack.l_mark[-11].flag && yystack.l_mark[-3].flag)
			 yyerror("use either imaps or set starttls");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_imap;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 if (yystack.l_mark[-9].userpass.user && yystack.l_mark[-9].userpass.pass == NULL) {
			 data->user = yystack.l_mark[-9].userpass.user;
			 find_netrc(yystack.l_mark[-10].server.host, &data->user, &data->pass);
		 } else if (yystack.l_mark[-9].userpass.user_netrc && yystack.l_mark[-9].userpass.pass_netrc)
			 find_netrc(yystack.l_mark[-10].server.host, &data->user, &data->pass);
		 else {
			 if (yystack.l_mark[-9].userpass.user_netrc)
				 find_netrc(yystack.l_mark[-10].server.host, &data->user, NULL);
			 else
				 data->user = yystack.l_mark[-9].userpass.user;
			 if (yystack.l_mark[-9].userpass.pass_netrc)
				 find_netrc(yystack.l_mark[-10].server.host, NULL, &data->pass);
			 else
				 data->pass = yystack.l_mark[-9].userpass.pass;
		 }

		 data->folder.str = yystack.l_mark[-8].string;
		 data->server.ssl = yystack.l_mark[-11].flag;
		 data->server.verify = yystack.l_mark[-7].flag;
		 data->server.host = yystack.l_mark[-10].server.host;
		 if (yystack.l_mark[-10].server.port != NULL)
			 data->server.port = yystack.l_mark[-10].server.port;
		 else if (yystack.l_mark[-11].flag)
			 data->server.port = xstrdup("imaps");
		 else
			 data->server.port = xstrdup("imap");
		 data->server.ai = NULL;
		 data->nocrammd5 = yystack.l_mark[-6].flag;
		 data->noplain = yystack.l_mark[-5].flag;
		 data->nologin = yystack.l_mark[-4].flag;
		 data->starttls = yystack.l_mark[-3].flag;
		 data->server.insecure = yystack.l_mark[-2].flag;
		 data->oauthbearer = yystack.l_mark[-2].flag;
		 data->xoauth2 = yystack.l_mark[-1].flag;
	 }
#line 4500 "parse.c"
break;
case 142:
#line 1273 "parse.y"
	{
		 struct deliver_smtp_data	*data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_smtp;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->server.host = yystack.l_mark[-2].server.host;
		 if (yystack.l_mark[-2].server.port != NULL)
			 data->server.port = yystack.l_mark[-2].server.port;
		 else
			 data->server.port = xstrdup("smtp");
		 data->server.ai = NULL;
		 data->from.str = yystack.l_mark[-1].string;
		 data->to.str = yystack.l_mark[0].string;
	 }
#line 4522 "parse.c"
break;
case 143:
#line 1292 "parse.y"
	{
		 struct deliver_lmtp_data       *data;

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_lmtp;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 if (*yystack.l_mark[-2].server.host == '/')
			data->socket = yystack.l_mark[-2].server.host;
		 else {
			data->server.host = yystack.l_mark[-2].server.host;
			if (yystack.l_mark[-2].server.port != NULL)
				data->server.port = yystack.l_mark[-2].server.port;
			else
				data->server.port = xstrdup("24");
		 }
		 data->from.str = yystack.l_mark[-1].string;
		 data->to.str = yystack.l_mark[0].string;
	 }
#line 4547 "parse.c"
break;
case 144:
#line 1314 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_stdout;
	 }
#line 4555 "parse.c"
break;
case 145:
#line 1319 "parse.y"
	{
		 struct deliver_tag_data	*data;

		 if (*yystack.l_mark[-1].string == '\0')
			 yyerror("invalid tag");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_tag;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[-1].string;
		 data->value.str = yystack.l_mark[0].string;
	 }
#line 4574 "parse.c"
break;
case 146:
#line 1335 "parse.y"
	{
		 struct deliver_add_to_cache_data	*data;

		 if (*yystack.l_mark[-2].string == '\0')
			 yyerror("invalid path");
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid key");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_add_to_cache;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[0].string;
		 data->path = yystack.l_mark[-2].string;
	 }
#line 4595 "parse.c"
break;
case 147:
#line 1353 "parse.y"
	{
		 struct deliver_remove_from_cache_data	*data;

		 if (*yystack.l_mark[-2].string == '\0')
			 yyerror("invalid path");
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid key");

		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_remove_from_cache;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->key.str = yystack.l_mark[0].string;
		 data->path = yystack.l_mark[-2].string;
	 }
#line 4616 "parse.c"
break;
case 148:
#line 1371 "parse.y"
	{
		 struct deliver_action_data	*data;

		 /*
		  * This is a special-case, handled when the list of delivery
		  * targets is resolved rather than by calling a deliver
		  * function, so the deliver pointer is NULL.
		  */
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = NULL;

		 data = xcalloc(1, sizeof *data);
		 yyval.actitem->data = data;

		 data->actions = yystack.l_mark[0].replstrs;
	 }
#line 4636 "parse.c"
break;
case 149:
#line 1388 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_drop;
	 }
#line 4644 "parse.c"
break;
case 150:
#line 1393 "parse.y"
	{
		 yyval.actitem = xcalloc(1, sizeof *yyval.actitem);
		 yyval.actitem->deliver = &deliver_keep;
	 }
#line 4652 "parse.c"
break;
case 151:
#line 1399 "parse.y"
	{
		 yyval.actlist = yystack.l_mark[-1].actlist;

		 TAILQ_INSERT_TAIL(yyval.actlist, yystack.l_mark[0].actitem, entry);
		 yystack.l_mark[0].actitem->idx = parse_actionidx++;
	 }
#line 4662 "parse.c"
break;
case 152:
#line 1406 "parse.y"
	{
		 yyval.actlist = xmalloc(sizeof *yyval.actlist);
		 TAILQ_INIT(yyval.actlist);

		 TAILQ_INSERT_HEAD(yyval.actlist, yystack.l_mark[0].actitem, entry);
		 yystack.l_mark[0].actitem->idx = 0;

		 parse_actionidx = 1;
	 }
#line 4675 "parse.c"
break;
case 153:
#line 1417 "parse.y"
	{
		   struct action	*t;

		   if (strlen(yystack.l_mark[-2].string) >= MAXNAMESIZE)
			   yyerror("action name too long: %s", yystack.l_mark[-2].string);
		   if (*yystack.l_mark[-2].string == '\0')
			   yyerror("invalid action name");
		   if (find_action(yystack.l_mark[-2].string) != NULL)
			   yyerror("duplicate action: %s", yystack.l_mark[-2].string);

		   t = xmalloc(sizeof *t);
		   strlcpy(t->name, yystack.l_mark[-2].string, sizeof t->name);

		   t->list = xmalloc(sizeof *t->list);
		   TAILQ_INIT(t->list);
		   TAILQ_INSERT_HEAD(t->list, yystack.l_mark[0].actitem, entry);
		   yystack.l_mark[0].actitem->idx = 0;

		   t->users = yystack.l_mark[-1].replstrs;
		   TAILQ_INSERT_TAIL(&conf.actions, t, entry);

		   print_action(t);

		   xfree(yystack.l_mark[-2].string);
	   }
#line 4704 "parse.c"
break;
case 154:
#line 1443 "parse.y"
	{
		   struct action	*t;

		   if (strlen(yystack.l_mark[-4].string) >= MAXNAMESIZE)
			   yyerror("action name too long: %s", yystack.l_mark[-4].string);
		   if (*yystack.l_mark[-4].string == '\0')
			   yyerror("invalid action name");
		   if (find_action(yystack.l_mark[-4].string) != NULL)
			   yyerror("duplicate action: %s", yystack.l_mark[-4].string);

		   t = xmalloc(sizeof *t);
		   strlcpy(t->name, yystack.l_mark[-4].string, sizeof t->name);

		   t->list = yystack.l_mark[-1].actlist;

		   t->users = yystack.l_mark[-3].replstrs;
		   TAILQ_INSERT_TAIL(&conf.actions, t, entry);

		   print_action(t);

		   xfree(yystack.l_mark[-4].string);
	   }
#line 4730 "parse.c"
break;
case 155:
#line 1467 "parse.y"
	{
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid account name");
		  if (!have_accounts(yystack.l_mark[0].string))
			  yyerror("no matching accounts: %s", yystack.l_mark[0].string);

		  yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		  ARRAY_INIT(yyval.replstrs);
		  ARRAY_EXPAND(yyval.replstrs, 1);
		  ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	  }
#line 4745 "parse.c"
break;
case 156:
#line 1479 "parse.y"
	{
		  yyval.replstrs = yystack.l_mark[-1].replstrs;
	  }
#line 4752 "parse.c"
break;
case 157:
#line 1484 "parse.y"
	{
		 if (*yystack.l_mark[0].string == '\0')
			 yyerror("invalid action name");

		 yyval.replstrs = xmalloc(sizeof *yyval.replstrs);
		 ARRAY_INIT(yyval.replstrs);
		 ARRAY_EXPAND(yyval.replstrs, 1);
		 ARRAY_LAST(yyval.replstrs).str = yystack.l_mark[0].string;
	 }
#line 4765 "parse.c"
break;
case 158:
#line 1494 "parse.y"
	{
		 yyval.replstrs = yystack.l_mark[-1].replstrs;
	 }
#line 4772 "parse.c"
break;
case 159:
#line 1499 "parse.y"
	{
	      yyval.flag = 0;
      }
#line 4779 "parse.c"
break;
case 160:
#line 1503 "parse.y"
	{
	      yyval.flag = 1;
      }
#line 4786 "parse.c"
break;
case 161:
#line 1508 "parse.y"
	{
	      yyval.area = AREA_ANY;
      }
#line 4793 "parse.c"
break;
case 162:
#line 1512 "parse.y"
	{
	      yyval.area = AREA_ANY;
      }
#line 4800 "parse.c"
break;
case 163:
#line 1516 "parse.y"
	{
	      yyval.area = AREA_HEADERS;
      }
#line 4807 "parse.c"
break;
case 164:
#line 1520 "parse.y"
	{
	      yyval.area = AREA_BODY;
      }
#line 4814 "parse.c"
break;
case 165:
#line 1525 "parse.y"
	{
	       if (yystack.l_mark[0].number < 0 || yystack.l_mark[0].number > 255)
		       yyerror("invalid return code");

	       yyval.number = yystack.l_mark[0].number;
       }
#line 4824 "parse.c"
break;
case 166:
#line 1532 "parse.y"
	{
	       yyval.number = -1;
       }
#line 4831 "parse.c"
break;
case 167:
#line 1537 "parse.y"
	{
	       yyval.re = yystack.l_mark[0].re;
       }
#line 4838 "parse.c"
break;
case 168:
#line 1541 "parse.y"
	{
	       yyval.re.str = NULL;
       }
#line 4845 "parse.c"
break;
case 169:
#line 1546 "parse.y"
	{
	     yyval.cmp = CMP_LT;
     }
#line 4852 "parse.c"
break;
case 170:
#line 1550 "parse.y"
	{
	     yyval.cmp = CMP_GT;
     }
#line 4859 "parse.c"
break;
case 171:
#line 1555 "parse.y"
	{
	      yyval.cmp = CMP_EQ;
      }
#line 4866 "parse.c"
break;
case 172:
#line 1559 "parse.y"
	{
	      yyval.cmp = CMP_NE;
      }
#line 4873 "parse.c"
break;
case 173:
#line 1564 "parse.y"
	{
	     yyval.cmp = yystack.l_mark[0].cmp;
     }
#line 4880 "parse.c"
break;
case 174:
#line 1568 "parse.y"
	{
	     yyval.cmp = yystack.l_mark[0].cmp;
     }
#line 4887 "parse.c"
break;
case 175:
#line 1573 "parse.y"
	{
		  yyval.flag = 0;
	  }
#line 4894 "parse.c"
break;
case 176:
#line 1577 "parse.y"
	{
		  yyval.flag = 1;
	  }
#line 4901 "parse.c"
break;
case 177:
#line 1582 "parse.y"
	{
		     yyval.flag = 0;
	     }
#line 4908 "parse.c"
break;
case 178:
#line 1586 "parse.y"
	{
		     yyval.flag = 1;
	     }
#line 4915 "parse.c"
break;
case 179:
#line 1591 "parse.y"
	{
		yyval.exprop = OP_AND;
	}
#line 4922 "parse.c"
break;
case 180:
#line 1595 "parse.y"
	{
		yyval.exprop = OP_OR;
	}
#line 4929 "parse.c"
break;
case 181:
#line 1600 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_all;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
	  }
#line 4938 "parse.c"
break;
case 182:
#line 1606 "parse.y"
	{
		  struct match_regexp_data	*data;
		  char				*cause;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_regexp;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->area = yystack.l_mark[0].area;

		  if (re_compile(&data->re, yystack.l_mark[-1].re.str, yystack.l_mark[-1].re.flags, &cause) != 0)
			  yyerror("%s", cause);
		  xfree(yystack.l_mark[-1].re.str);
	  }
#line 4959 "parse.c"
break;
case 183:
#line 1624 "parse.y"
	{
		  struct match_account_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_account;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->accounts = yystack.l_mark[0].replstrs;
	  }
#line 4975 "parse.c"
break;
case 184:
#line 1637 "parse.y"
	{
		  struct match_command_data	*data;
		  char				*cause;

		  if (*yystack.l_mark[-7].string == '\0' || (yystack.l_mark[-7].string[0] == '|' && yystack.l_mark[-7].string[1] == '\0'))
			  yyerror("invalid command");
		  if (yystack.l_mark[-3].number == -1 && yystack.l_mark[-1].re.str == NULL)
			  yyerror("return code or regexp must be specified");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);
		  yyval.expritem->match = &match_command;
		  yyval.expritem->inverted = yystack.l_mark[-9].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->user.str = yystack.l_mark[-6].string;
		  data->pipe = yystack.l_mark[-8].flag;
		  data->cmd.str = yystack.l_mark[-7].string;

		  data->ret = yystack.l_mark[-3].number;

		  if (yystack.l_mark[-1].re.str != NULL) {
			  if (re_compile(
			      &data->re, yystack.l_mark[-1].re.str, yystack.l_mark[-1].re.flags, &cause) != 0)
				  yyerror("%s", cause);
			  xfree(yystack.l_mark[-1].re.str);
		  }

	  }
#line 5009 "parse.c"
break;
case 185:
#line 1668 "parse.y"
	{
		  struct match_tagged_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid tag");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_tagged;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->tag.str = yystack.l_mark[0].string;
	  }
#line 5029 "parse.c"
break;
case 186:
#line 1685 "parse.y"
	{
		  struct match_size_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_size;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->size = yystack.l_mark[0].number;
		  data->cmp = yystack.l_mark[-1].cmp;
	  }
#line 5052 "parse.c"
break;
case 187:
#line 1705 "parse.y"
	{
		  struct match_string_data	*data;
		  char				*cause;

		  if (*yystack.l_mark[-2].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_string;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->str.str = yystack.l_mark[-2].string;
		  if (re_compile(
		      &data->re, yystack.l_mark[0].re.str, yystack.l_mark[0].re.flags|RE_NOSUBST, &cause) != 0)
			  yyerror("%s", cause);
		  xfree(yystack.l_mark[0].re.str);
	  }
#line 5077 "parse.c"
break;
case 188:
#line 1727 "parse.y"
	{
		  struct match_in_cache_data	*data;

		  if (*yystack.l_mark[-2].string == '\0')
			  yyerror("invalid path");
		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid key");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_in_cache;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->key.str = yystack.l_mark[0].string;
		  data->path = yystack.l_mark[-2].string;
	  }
#line 5100 "parse.c"
break;
case 189:
#line 1747 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_matched;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
	  }
#line 5110 "parse.c"
break;
case 190:
#line 1754 "parse.y"
	{
		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_unmatched;
		  yyval.expritem->inverted = yystack.l_mark[-1].flag;
	  }
#line 5120 "parse.c"
break;
case 191:
#line 1761 "parse.y"
	{
		  struct match_age_data	*data;

		  if (yystack.l_mark[0].number == 0)
			  yyerror("invalid time");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_age;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->time = yystack.l_mark[0].number;
		  data->cmp = yystack.l_mark[-1].cmp;
	  }
#line 5141 "parse.c"
break;
case 192:
#line 1779 "parse.y"
	{
		  struct match_age_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_age;
		  yyval.expritem->inverted = yystack.l_mark[-2].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->time = -1;
	  }
#line 5158 "parse.c"
break;
case 193:
#line 1793 "parse.y"
	{
		  struct match_attachment_data	*data;

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_COUNT;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.num = yystack.l_mark[0].number;
	  }
#line 5177 "parse.c"
break;
case 194:
#line 1809 "parse.y"
	{
		  struct match_attachment_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_TOTALSIZE;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.size = yystack.l_mark[0].number;
	  }
#line 5201 "parse.c"
break;
case 195:
#line 1830 "parse.y"
	{
		  struct match_attachment_data	*data;

#if SIZE_MAX < LLONG_MAX
		  if (yystack.l_mark[0].number > SIZE_MAX)
			  yyerror("size too large");
#endif

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-4].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYSIZE;
		  data->cmp = yystack.l_mark[-1].cmp;
		  data->value.size = yystack.l_mark[0].number;
	  }
#line 5225 "parse.c"
break;
case 196:
#line 1851 "parse.y"
	{
		  struct match_attachment_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYTYPE;
		  data->value.str.str = yystack.l_mark[0].string;
	  }
#line 5246 "parse.c"
break;
case 197:
#line 1869 "parse.y"
	{
		  struct match_attachment_data	*data;

		  if (*yystack.l_mark[0].string == '\0')
			  yyerror("invalid string");

		  yyval.expritem = xcalloc(1, sizeof *yyval.expritem);

		  yyval.expritem->match = &match_attachment;
		  yyval.expritem->inverted = yystack.l_mark[-3].flag;

		  data = xcalloc(1, sizeof *data);
		  yyval.expritem->data = data;

		  data->op = ATTACHOP_ANYNAME;
		  data->value.str.str = yystack.l_mark[0].string;
	  }
#line 5267 "parse.c"
break;
case 198:
#line 1888 "parse.y"
	{
		  yyval.expr = yystack.l_mark[-2].expr;

		  yystack.l_mark[0].expritem->op = yystack.l_mark[-1].exprop;
		  TAILQ_INSERT_TAIL(yyval.expr, yystack.l_mark[0].expritem, entry);
	  }
#line 5277 "parse.c"
break;
case 199:
#line 1895 "parse.y"
	{
		  yyval.expr = xmalloc(sizeof *yyval.expr);
		  TAILQ_INIT(yyval.expr);

		  yystack.l_mark[0].expritem->op = yystack.l_mark[-1].exprop;
		  TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[0].expritem, entry);
	  }
#line 5288 "parse.c"
break;
case 200:
#line 1904 "parse.y"
	{
	      yyval.expr = xmalloc(sizeof *yyval.expr);
	      TAILQ_INIT(yyval.expr);

	      TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[0].expritem, entry);
      }
#line 5298 "parse.c"
break;
case 201:
#line 1911 "parse.y"
	{
	      yyval.expr = yystack.l_mark[0].expr;

	      TAILQ_INSERT_HEAD(yyval.expr, yystack.l_mark[-1].expritem, entry);
      }
#line 5307 "parse.c"
break;
case 202:
#line 1918 "parse.y"
	{
		 struct action	*t;

		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-3].replstrs;

		 t = yyval.rule->lambda = xcalloc(1, sizeof *yyval.rule->lambda);
		 xsnprintf(t->name, sizeof t->name, "<rule %u>", yyval.rule->idx);
		 t->users = NULL;
		 t->list = xmalloc(sizeof *t->list);
		 TAILQ_INIT(t->list);
		 TAILQ_INSERT_HEAD(t->list, yystack.l_mark[-1].actitem, entry);
		 yystack.l_mark[-1].actitem->idx = 0;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
#line 5334 "parse.c"
break;
case 203:
#line 1942 "parse.y"
	{
		 struct action	*t;

		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-5].replstrs;

		 t = yyval.rule->lambda = xcalloc(1, sizeof *yyval.rule->lambda);
		 xsnprintf(t->name, sizeof t->name, "<rule %u>", yyval.rule->idx);
		 t->users = NULL;
		 t->list = yystack.l_mark[-2].actlist;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
#line 5358 "parse.c"
break;
case 204:
#line 1963 "parse.y"
	{
		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->lambda = NULL;
		 yyval.rule->actions = yystack.l_mark[-1].replstrs;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = !yystack.l_mark[0].flag;
		 yyval.rule->users = yystack.l_mark[-2].replstrs;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);
	 }
#line 5376 "parse.c"
break;
case 205:
#line 1978 "parse.y"
	{
		 yyval.rule = xcalloc(1, sizeof *yyval.rule);
		 yyval.rule->idx = parse_ruleidx++;
		 yyval.rule->lambda = NULL;
		 yyval.rule->actions = NULL;
		 TAILQ_INIT(&yyval.rule->rules);
		 yyval.rule->stop = 0;
		 yyval.rule->users = NULL;

		 if (parse_rule == NULL)
			 TAILQ_INSERT_TAIL(&conf.rules, yyval.rule, entry);
		 else
			 TAILQ_INSERT_TAIL(&parse_rule->rules, yyval.rule, entry);

		 ARRAY_ADD(&parse_rulestack, parse_rule);
		 parse_rule = yyval.rule;
	 }
#line 5397 "parse.c"
break;
case 206:
#line 1997 "parse.y"
	{
	       if (parse_rule == NULL)
		       yyerror("missing {");

	       parse_rule = ARRAY_LAST(&parse_rulestack);
	       ARRAY_TRUNC(&parse_rulestack, 1);
       }
#line 5408 "parse.c"
break;
case 207:
#line 2006 "parse.y"
	{
	      yystack.l_mark[0].rule->expr = yystack.l_mark[-1].expr;
	      print_rule(yystack.l_mark[0].rule);
      }
#line 5416 "parse.c"
break;
case 208:
#line 2012 "parse.y"
	{
		    yyval.strings = xmalloc(sizeof *yyval.strings);
		    ARRAY_INIT(yyval.strings);
		    ARRAY_ADD(yyval.strings, xstrdup("INBOX"));
	    }
#line 5425 "parse.c"
break;
case 209:
#line 2018 "parse.y"
	{
		    yyval.strings = yystack.l_mark[0].strings;
	    }
#line 5432 "parse.c"
break;
case 210:
#line 2023 "parse.y"
	{
		 yyval.string = xstrdup("INBOX");
	 }
#line 5439 "parse.c"
break;
case 211:
#line 2027 "parse.y"
	{
		 yyval.string = yystack.l_mark[0].string;
	 }
#line 5446 "parse.c"
break;
case 212:
#line 2033 "parse.y"
	{
		if (*yystack.l_mark[0].string == '\0')
			yyerror("invalid group");

		yyval.strings = xmalloc(sizeof *yyval.strings);
		ARRAY_INIT(yyval.strings);
		ARRAY_ADD(yyval.strings, yystack.l_mark[0].string);
	}
#line 5458 "parse.c"
break;
case 213:
#line 2042 "parse.y"
	{
		yyval.strings = yystack.l_mark[-1].strings;
	}
#line 5465 "parse.c"
break;
case 214:
#line 2047 "parse.y"
	{
		   yyval.flag = 1;
	   }
#line 5472 "parse.c"
break;
case 215:
#line 2051 "parse.y"
	{
		   yyval.flag = 0;
	   }
#line 5479 "parse.c"
break;
case 216:
#line 2056 "parse.y"
	{
		 yyval.flag = 1;
	 }
#line 5486 "parse.c"
break;
case 217:
#line 2060 "parse.y"
	{
		 yyval.flag = 0;
	 }
#line 5493 "parse.c"
break;
case 218:
#line 2065 "parse.y"
	{
		 yyval.flag = 1;
	 }
#line 5500 "parse.c"
break;
case 219:
#line 2069 "parse.y"
	{
		 yyval.flag = 0;
	 }
#line 5507 "parse.c"
break;
case 220:
#line 2074 "parse.y"
	{
		  yyval.flag = 1;
	  }
#line 5514 "parse.c"
break;
case 221:
#line 2078 "parse.y"
	{
		  yyval.flag = 0;
	  }
#line 5521 "parse.c"
break;
case 222:
#line 2084 "parse.y"
	{
	      yyval.flag = 0;
      }
#line 5528 "parse.c"
break;
case 223:
#line 2088 "parse.y"
	{
	      yyval.flag = 1;
      }
#line 5535 "parse.c"
break;
case 224:
#line 2093 "parse.y"
	{
		  yyval.flag = 1;
	  }
#line 5542 "parse.c"
break;
case 225:
#line 2097 "parse.y"
	{
		  yyval.flag = 0;
	  }
#line 5549 "parse.c"
break;
case 226:
#line 2102 "parse.y"
	{
		     yyval.flag = 1;
	     }
#line 5556 "parse.c"
break;
case 227:
#line 2106 "parse.y"
	{
		     yyval.flag = 0;
	     }
#line 5563 "parse.c"
break;
case 228:
#line 2111 "parse.y"
	{
		 yyval.flag = 1;
	 }
#line 5570 "parse.c"
break;
case 229:
#line 2115 "parse.y"
	{
		 yyval.flag = 0;
	 }
#line 5577 "parse.c"
break;
case 230:
#line 2120 "parse.y"
	{
		yyval.flag = 0;
	}
#line 5584 "parse.c"
break;
case 231:
#line 2124 "parse.y"
	{
		yyval.flag = 1;
	}
#line 5591 "parse.c"
break;
case 232:
#line 2129 "parse.y"
	{
	      yyval.flag = 0;
      }
#line 5598 "parse.c"
break;
case 233:
#line 2133 "parse.y"
	{
	      yyval.flag = 1;
      }
#line 5605 "parse.c"
break;
case 234:
#line 2138 "parse.y"
	{
	      yyval.only = FETCH_ONLY_NEW;
      }
#line 5612 "parse.c"
break;
case 235:
#line 2142 "parse.y"
	{
	      yyval.only = FETCH_ONLY_OLD;
      }
#line 5619 "parse.c"
break;
case 236:
#line 2147 "parse.y"
	{
		 yyval.flag = 0;
	 }
#line 5626 "parse.c"
break;
case 237:
#line 2151 "parse.y"
	{
		 yyval.flag = 1;
	 }
#line 5633 "parse.c"
break;
case 238:
#line 2156 "parse.y"
	{
		  yyval.flag = 0;
	  }
#line 5640 "parse.c"
break;
case 239:
#line 2160 "parse.y"
	{
		  yyval.flag = 1;
	  }
#line 5647 "parse.c"
break;
case 240:
#line 2165 "parse.y"
	{
		  yyval.flag = 0;
	  }
#line 5654 "parse.c"
break;
case 241:
#line 2169 "parse.y"
	{
		  yyval.flag = 1;
	  }
#line 5661 "parse.c"
break;
case 242:
#line 2174 "parse.y"
	{
		       if (*yystack.l_mark[-2].string == '\0')
			       yyerror("invalid user");
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid pass");

		       yyval.userpass.user = yystack.l_mark[-2].string;
		       yyval.userpass.user_netrc = 0;
		       yyval.userpass.pass = yystack.l_mark[0].string;
		       yyval.userpass.pass_netrc = 0;
	       }
#line 5676 "parse.c"
break;
case 243:
#line 2186 "parse.y"
	{
		       yyval.userpass.user = NULL;
		       yyval.userpass.user_netrc = 1;
		       yyval.userpass.pass = NULL;
		       yyval.userpass.pass_netrc = 1;
	       }
#line 5686 "parse.c"
break;
case 244:
#line 2193 "parse.y"
	{
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid user");

		       yyval.userpass.user = yystack.l_mark[0].string;
		       yyval.userpass.user_netrc = 0;
		       yyval.userpass.pass = NULL;
		       yyval.userpass.pass_netrc = 1;
	       }
#line 5699 "parse.c"
break;
case 245:
#line 2203 "parse.y"
	{
		       if (*yystack.l_mark[0].string == '\0')
			       yyerror("invalid pass");

		       yyval.userpass.user = NULL;
		       yyval.userpass.user_netrc = 1;
		       yyval.userpass.pass = yystack.l_mark[0].string;
		       yyval.userpass.pass_netrc = 0;
	       }
#line 5712 "parse.c"
break;
case 246:
#line 2214 "parse.y"
	{
		      if (*yystack.l_mark[-2].string == '\0')
			      yyerror("invalid user");
		      if (*yystack.l_mark[0].string == '\0')
			      yyerror("invalid pass");

		      yyval.userpass.user = yystack.l_mark[-2].string;
		      yyval.userpass.user_netrc = 0;
		      yyval.userpass.pass = yystack.l_mark[0].string;
		      yyval.userpass.pass_netrc = 0;
	      }
#line 5727 "parse.c"
break;
case 247:
#line 2227 "parse.y"
	{
		  yyval.userpass.user = yystack.l_mark[0].userpass.user;
		  yyval.userpass.user_netrc = yystack.l_mark[0].userpass.user_netrc;
		  yyval.userpass.pass = yystack.l_mark[0].userpass.pass;
		  yyval.userpass.pass_netrc = yystack.l_mark[0].userpass.pass_netrc;
	  }
#line 5737 "parse.c"
break;
case 248:
#line 2234 "parse.y"
	{
		  yyval.userpass.user = NULL;
		  yyval.userpass.user_netrc = 0;
		  yyval.userpass.pass = NULL;
		  yyval.userpass.pass_netrc = 0;
	  }
#line 5747 "parse.c"
break;
case 249:
#line 2242 "parse.y"
	{
		 yyval.poponly.path = yystack.l_mark[0].string;
		 yyval.poponly.only = yystack.l_mark[-2].only;
	 }
#line 5755 "parse.c"
break;
case 250:
#line 2247 "parse.y"
	{
		 yyval.poponly.path = NULL;
		 yyval.poponly.only = FETCH_ONLY_ALL;
	 }
#line 5763 "parse.c"
break;
case 251:
#line 2253 "parse.y"
	{
		  yyval.only = yystack.l_mark[0].only;
	  }
#line 5770 "parse.c"
break;
case 252:
#line 2257 "parse.y"
	{
		  yyval.only = FETCH_ONLY_ALL;
	  }
#line 5777 "parse.c"
break;
case 253:
#line 2263 "parse.y"
	{
		   struct fetch_pop3_data	*data;

		   if (yystack.l_mark[-8].flag && yystack.l_mark[-1].flag)
			   yyerror("use either pop3s or set starttls");

		   yyval.fetch.fetch = &fetch_pop3;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-6].userpass.user && yystack.l_mark[-6].userpass.pass == NULL) {
			   data->user = yystack.l_mark[-6].userpass.user;
			   find_netrc(yystack.l_mark[-7].server.host, &data->user, &data->pass);
		   } else if (yystack.l_mark[-6].userpass.user_netrc && yystack.l_mark[-6].userpass.pass_netrc)
			  find_netrc(yystack.l_mark[-7].server.host, &data->user, &data->pass);
		   else {
			   if (yystack.l_mark[-6].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-7].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-6].userpass.user;
			   if (yystack.l_mark[-6].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-7].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-6].userpass.pass;
		   }

		   data->server.ssl = yystack.l_mark[-8].flag;
		   data->server.verify = yystack.l_mark[-3].flag;
		   data->server.host = yystack.l_mark[-7].server.host;
		   if (yystack.l_mark[-7].server.port != NULL)
			   data->server.port = yystack.l_mark[-7].server.port;
		   else if (yystack.l_mark[-8].flag)
			   data->server.port = xstrdup("pop3s");
		   else
			   data->server.port = xstrdup("pop3");
		   data->server.ai = NULL;
		   data->apop = yystack.l_mark[-4].flag;
		   data->uidl = yystack.l_mark[-2].flag;
		   data->starttls = yystack.l_mark[-1].flag;
		   data->server.insecure = yystack.l_mark[0].flag;

		   data->path = yystack.l_mark[-5].poponly.path;
		   data->only = yystack.l_mark[-5].poponly.only;
	   }
#line 5825 "parse.c"
break;
case 254:
#line 2308 "parse.y"
	{
		   struct fetch_pop3_data	*data;

		   yyval.fetch.fetch = &fetch_pop3pipe;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->user = yystack.l_mark[-2].userpass.user;
		   data->pass = yystack.l_mark[-2].userpass.pass;
		   data->pipecmd = yystack.l_mark[-3].string;
		   if (data->pipecmd == NULL || *data->pipecmd == '\0')
			   yyerror("invalid pipe command");
		   data->apop = yystack.l_mark[0].flag;
		   data->path = yystack.l_mark[-1].poponly.path;
		   data->only = yystack.l_mark[-1].poponly.only;
	   }
#line 5844 "parse.c"
break;
case 255:
#line 2325 "parse.y"
	{
		   struct fetch_imap_data	*data;

		   if (yystack.l_mark[-12].flag && yystack.l_mark[-3].flag)
			   yyerror("use either imaps or set starttls");

		   yyval.fetch.fetch = &fetch_imap;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-10].userpass.user && yystack.l_mark[-10].userpass.pass == NULL) {
			   data->user = yystack.l_mark[-10].userpass.user;
			   find_netrc(yystack.l_mark[-11].server.host, &data->user, &data->pass);
		   } else if (yystack.l_mark[-10].userpass.user_netrc && yystack.l_mark[-10].userpass.pass_netrc)
			   find_netrc(yystack.l_mark[-11].server.host, &data->user, &data->pass);
		   else {
			   if (yystack.l_mark[-10].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-11].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-10].userpass.user;
			   if (yystack.l_mark[-10].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-11].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-10].userpass.pass;
		   }

		   data->folders = yystack.l_mark[-9].strings;
		   data->server.ssl = yystack.l_mark[-12].flag;
		   data->server.verify = yystack.l_mark[-7].flag;
		   data->server.host = yystack.l_mark[-11].server.host;
		   if (yystack.l_mark[-11].server.port != NULL)
			   data->server.port = yystack.l_mark[-11].server.port;
		   else if (yystack.l_mark[-12].flag)
			   data->server.port = xstrdup("imaps");
		   else
			   data->server.port = xstrdup("imap");
		   data->server.ai = NULL;
		   data->only = yystack.l_mark[-8].only;
		   data->nocrammd5 = yystack.l_mark[-6].flag;
		   data->noplain = yystack.l_mark[-5].flag;
		   data->nologin = yystack.l_mark[-4].flag;
		   data->starttls = yystack.l_mark[-3].flag;
		   data->server.insecure = yystack.l_mark[-2].flag;
		   data->oauthbearer = yystack.l_mark[-1].flag;
		   data->xoauth2 = yystack.l_mark[0].flag;
	   }
#line 5894 "parse.c"
break;
case 256:
#line 2372 "parse.y"
	{
		   struct fetch_imap_data	*data;

		   yyval.fetch.fetch = &fetch_imappipe;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->user = yystack.l_mark[-2].userpass.user;
		   data->pass = yystack.l_mark[-2].userpass.pass;
		   data->folders = yystack.l_mark[-1].strings;
		   data->pipecmd = yystack.l_mark[-3].string;
		   if (data->pipecmd == NULL || *data->pipecmd == '\0')
			   yyerror("invalid pipe command");
		   data->only = yystack.l_mark[0].only;
	   }
#line 5912 "parse.c"
break;
case 257:
#line 2387 "parse.y"
	{
		   yyval.fetch.fetch = &fetch_stdin;
	   }
#line 5919 "parse.c"
break;
case 258:
#line 2391 "parse.y"
	{
		   struct fetch_maildir_data	*data;

		   yyval.fetch.fetch = &fetch_maildir;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->maildirs = yystack.l_mark[0].strings;
	   }
#line 5931 "parse.c"
break;
case 259:
#line 2400 "parse.y"
	{
		   struct fetch_mbox_data	*data;

		   yyval.fetch.fetch = &fetch_mbox;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;
		   data->mboxes = yystack.l_mark[0].strings;
	   }
#line 5943 "parse.c"
break;
case 260:
#line 2410 "parse.y"
	{
		   struct fetch_nntp_data	*data;
		   char				*cause;

		   if (*yystack.l_mark[-2].string == '\0')
			   yyerror("invalid cache");

		   yyval.fetch.fetch = &fetch_nntp;
		   data = xcalloc(1, sizeof *data);
		   yyval.fetch.data = data;

		   if (yystack.l_mark[-5].userpass.user && yystack.l_mark[-5].userpass.pass == NULL) {
			   data->user = yystack.l_mark[-5].userpass.user;
			   find_netrc(yystack.l_mark[-6].server.host, &data->user, &data->pass);
		   } else if (yystack.l_mark[-5].userpass.user_netrc && yystack.l_mark[-5].userpass.pass_netrc) {
			   if (find_netrc1(yystack.l_mark[-6].server.host, &data->user, &data->pass,
			       &cause) != 0) {
				   log_debug2("%s", cause);
				   xfree(cause);
				   data->user = NULL;
				   data->pass = NULL;
			   }
		   } else {
			   if (yystack.l_mark[-5].userpass.user_netrc)
				   find_netrc(yystack.l_mark[-6].server.host, &data->user, NULL);
			   else
				   data->user = yystack.l_mark[-5].userpass.user;
			   if (yystack.l_mark[-5].userpass.pass_netrc)
				   find_netrc(yystack.l_mark[-6].server.host, NULL, &data->pass);
			   else
				   data->pass = yystack.l_mark[-5].userpass.pass;
		   }

		   data->names = yystack.l_mark[-4].strings;
		   data->path = yystack.l_mark[-2].string;
		   if (data->path == NULL || *data->path == '\0')
			   yyerror("invalid cache");

		   data->server.ssl = yystack.l_mark[-7].flag;
		   data->server.verify = yystack.l_mark[-1].flag;
		   data->server.insecure = yystack.l_mark[0].flag;
		   data->server.host = yystack.l_mark[-6].server.host;
		   if (yystack.l_mark[-6].server.port != NULL)
			   data->server.port = yystack.l_mark[-6].server.port;
		   else if (yystack.l_mark[-7].flag)
			   data->server.port = xstrdup("nntps");
		   else
			   data->server.port = xstrdup("nntp");
		   data->server.ai = NULL;
	   }
#line 5997 "parse.c"
break;
case 261:
#line 2462 "parse.y"
	{
		 struct account		*a;
		 char			*su, desc[DESCBUFSIZE];

		 if (strlen(yystack.l_mark[-4].string) >= MAXNAMESIZE)
			 yyerror("account name too long: %s", yystack.l_mark[-4].string);
		 if (*yystack.l_mark[-4].string == '\0')
			 yyerror("invalid account name");
		 if (find_account(yystack.l_mark[-4].string) != NULL)
			 yyerror("duplicate account: %s", yystack.l_mark[-4].string);

		 a = xcalloc(1, sizeof *a);
		 strlcpy(a->name, yystack.l_mark[-4].string, sizeof a->name);
		 a->keep = yystack.l_mark[0].flag;
		 a->disabled = yystack.l_mark[-3].flag;
		 a->users = yystack.l_mark[-2].replstrs;
		 a->fetch = yystack.l_mark[-1].fetch.fetch;
		 a->data = yystack.l_mark[-1].fetch.data;
		 TAILQ_INSERT_TAIL(&conf.accounts, a, entry);

		 if (a->users != NULL)
			 su = fmt_replstrs(" users=", a->users);
		 else
			 su = xstrdup("");
		 a->fetch->desc(a, desc, sizeof desc);
		 log_debug2("added account \"%s\":%s fetch=%s", a->name, su,
		     desc);
		 xfree(su);

		 xfree(yystack.l_mark[-4].string);
	 }
#line 6032 "parse.c"
break;
#line 6034 "parse.c"
    default:
        break;
    }
    yystack.s_mark -= yym;
    yystate = *yystack.s_mark;
    yystack.l_mark -= yym;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    yystack.p_mark -= yym;
#endif
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
        {
            fprintf(stderr, "%s[%d]: after reduction, ", YYDEBUGSTR, yydepth);
#ifdef YYSTYPE_TOSTRING
#if YYBTYACC
            if (!yytrial)
#endif /* YYBTYACC */
                fprintf(stderr, "result is <%s>, ", YYSTYPE_TOSTRING(yystos[YYFINAL], yyval));
#endif
            fprintf(stderr, "shifting from state 0 to final state %d\n", YYFINAL);
        }
#endif
        yystate = YYFINAL;
        *++yystack.s_mark = YYFINAL;
        *++yystack.l_mark = yyval;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
        *++yystack.p_mark = yyloc;
#endif
        if (yychar < 0)
        {
#if YYBTYACC
            do {
            if (yylvp < yylve)
            {
                /* we're currently re-reading tokens */
                yylval = *yylvp++;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                yylloc = *yylpp++;
#endif
                yychar = *yylexp++;
                break;
            }
            if (yyps->save)
            {
                /* in trial mode; save scanner results for future parse attempts */
                if (yylvp == yylvlim)
                {   /* Enlarge lexical value queue */
                    size_t p = (size_t) (yylvp - yylvals);
                    size_t s = (size_t) (yylvlim - yylvals);

                    s += YYLVQUEUEGROWTH;
                    if ((yylexemes = (YYINT *)realloc(yylexemes, s * sizeof(YYINT))) == NULL)
                        goto yyenomem;
                    if ((yylvals   = (YYSTYPE *)realloc(yylvals, s * sizeof(YYSTYPE))) == NULL)
                        goto yyenomem;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                    if ((yylpsns   = (YYLTYPE *)realloc(yylpsns, s * sizeof(YYLTYPE))) == NULL)
                        goto yyenomem;
#endif
                    yylvp   = yylve = yylvals + p;
                    yylvlim = yylvals + s;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                    yylpp   = yylpe = yylpsns + p;
                    yylplim = yylpsns + s;
#endif
                    yylexp  = yylexemes + p;
                }
                *yylexp = (YYINT) YYLEX;
                *yylvp++ = yylval;
                yylve++;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
                *yylpp++ = yylloc;
                yylpe++;
#endif
                yychar = *yylexp++;
                break;
            }
            /* normal operation, no conflict encountered */
#endif /* YYBTYACC */
            yychar = YYLEX;
#if YYBTYACC
            } while (0);
#endif /* YYBTYACC */
            if (yychar < 0) yychar = YYEOF;
#if YYDEBUG
            if (yydebug)
            {
                if ((yys = yyname[YYTRANSLATE(yychar)]) == NULL) yys = yyname[YYUNDFTOKEN];
                fprintf(stderr, "%s[%d]: state %d, reading token %d (%s)\n",
                                YYDEBUGSTR, yydepth, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == YYEOF) goto yyaccept;
        goto yyloop;
    }
    if (((yyn = yygindex[yym]) != 0) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
    {
        fprintf(stderr, "%s[%d]: after reduction, ", YYDEBUGSTR, yydepth);
#ifdef YYSTYPE_TOSTRING
#if YYBTYACC
        if (!yytrial)
#endif /* YYBTYACC */
            fprintf(stderr, "result is <%s>, ", YYSTYPE_TOSTRING(yystos[yystate], yyval));
#endif
        fprintf(stderr, "shifting from state %d to state %d\n", *yystack.s_mark, yystate);
    }
#endif
    if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack) == YYENOMEM) goto yyoverflow;
    *++yystack.s_mark = (YYINT) yystate;
    *++yystack.l_mark = yyval;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    *++yystack.p_mark = yyloc;
#endif
    goto yyloop;
#if YYBTYACC

    /* Reduction declares that this path is valid. Set yypath and do a full parse */
yyvalid:
    if (yypath) YYABORT;
    while (yyps->save)
    {
        YYParseState *save = yyps->save;
        yyps->save = save->save;
        save->save = yypath;
        yypath = save;
    }
#if YYDEBUG
    if (yydebug)
        fprintf(stderr, "%s[%d]: state %d, CONFLICT trial successful, backtracking to state %d, %d tokens\n",
                        YYDEBUGSTR, yydepth, yystate, yypath->state, (int)(yylvp - yylvals - yypath->lexeme));
#endif
    if (yyerrctx)
    {
        yyFreeState(yyerrctx);
        yyerrctx = NULL;
    }
    yylvp          = yylvals + yypath->lexeme;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    yylpp          = yylpsns + yypath->lexeme;
#endif
    yylexp         = yylexemes + yypath->lexeme;
    yychar         = YYEMPTY;
    yystack.s_mark = yystack.s_base + (yypath->yystack.s_mark - yypath->yystack.s_base);
    memcpy (yystack.s_base, yypath->yystack.s_base, (size_t) (yystack.s_mark - yystack.s_base + 1) * sizeof(YYINT));
    yystack.l_mark = yystack.l_base + (yypath->yystack.l_mark - yypath->yystack.l_base);
    memcpy (yystack.l_base, yypath->yystack.l_base, (size_t) (yystack.l_mark - yystack.l_base + 1) * sizeof(YYSTYPE));
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
    yystack.p_mark = yystack.p_base + (yypath->yystack.p_mark - yypath->yystack.p_base);
    memcpy (yystack.p_base, yypath->yystack.p_base, (size_t) (yystack.p_mark - yystack.p_base + 1) * sizeof(YYLTYPE));
#endif
    yystate        = yypath->state;
    goto yyloop;
#endif /* YYBTYACC */

yyoverflow:
    YYERROR_CALL("yacc stack overflow");
#if YYBTYACC
    goto yyabort_nomem;
yyenomem:
    YYERROR_CALL("memory exhausted");
yyabort_nomem:
#endif /* YYBTYACC */
    yyresult = 2;
    goto yyreturn;

yyabort:
    yyresult = 1;
    goto yyreturn;

yyaccept:
#if YYBTYACC
    if (yyps->save) goto yyvalid;
#endif /* YYBTYACC */
    yyresult = 0;

yyreturn:
#if defined(YYDESTRUCT_CALL)
    if (yychar != YYEOF && yychar != YYEMPTY)
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
        YYDESTRUCT_CALL("cleanup: discarding token", yychar, &yylval, &yylloc);
#else
        YYDESTRUCT_CALL("cleanup: discarding token", yychar, &yylval);
#endif /* defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED) */

    {
        YYSTYPE *pv;
#if defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED)
        YYLTYPE *pp;

        for (pv = yystack.l_base, pp = yystack.p_base; pv <= yystack.l_mark; ++pv, ++pp)
             YYDESTRUCT_CALL("cleanup: discarding state",
                             yystos[*(yystack.s_base + (pv - yystack.l_base))], pv, pp);
#else
        for (pv = yystack.l_base; pv <= yystack.l_mark; ++pv)
             YYDESTRUCT_CALL("cleanup: discarding state",
                             yystos[*(yystack.s_base + (pv - yystack.l_base))], pv);
#endif /* defined(YYLTYPE) || defined(YYLTYPE_IS_DECLARED) */
    }
#endif /* defined(YYDESTRUCT_CALL) */

#if YYBTYACC
    if (yyerrctx)
    {
        yyFreeState(yyerrctx);
        yyerrctx = NULL;
    }
    while (yyps)
    {
        YYParseState *save = yyps;
        yyps = save->save;
        save->save = NULL;
        yyFreeState(save);
    }
    while (yypath)
    {
        YYParseState *save = yypath;
        yypath = save->save;
        save->save = NULL;
        yyFreeState(save);
    }
#endif /* YYBTYACC */
    yyfreestack(&yystack);
    return (yyresult);
}
